# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-07-08 19:45
from __future__ import unicode_literals

import autoslug.fields
import bpp.fields
from decimal import Decimal
import django.contrib.auth.validators
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0077_auto_20170624_0130'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='autor',
            options={'ordering': ['sort'], 'verbose_name': 'autor', 'verbose_name_plural': 'autorzy'},
        ),
        migrations.AlterModelOptions(
            name='charakter_formalny',
            options={'ordering': ['nazwa'], 'verbose_name': 'charakter formalny', 'verbose_name_plural': 'charaktery formalne'},
        ),
        migrations.AlterModelOptions(
            name='funkcja_autora',
            options={'ordering': ['nazwa'], 'verbose_name': 'funkcja w jednostce', 'verbose_name_plural': 'funkcje w jednostkach'},
        ),
        migrations.AlterModelOptions(
            name='jednostka',
            options={'ordering': ['nazwa'], 'verbose_name': 'jednostka', 'verbose_name_plural': 'jednostki'},
        ),
        migrations.AlterModelOptions(
            name='patent',
            options={'verbose_name': 'patent', 'verbose_name_plural': 'patenty'},
        ),
        migrations.AlterModelOptions(
            name='praca_doktorska',
            options={'verbose_name': 'praca doktorska', 'verbose_name_plural': 'prace doktorskie'},
        ),
        migrations.AlterModelOptions(
            name='praca_habilitacyjna',
            options={'verbose_name': 'praca habilitacyjna', 'verbose_name_plural': 'prace habilitacyjne'},
        ),
        migrations.AlterModelOptions(
            name='status_korekty',
            options={'verbose_name': 'status korekty', 'verbose_name_plural': 'statusy korekty'},
        ),
        migrations.AlterModelOptions(
            name='typ_kbn',
            options={'ordering': ['nazwa'], 'verbose_name': 'typ KBN', 'verbose_name_plural': 'typy KBN'},
        ),
        migrations.AlterModelOptions(
            name='uczelnia',
            options={'verbose_name': 'uczelnia', 'verbose_name_plural': 'uczelnie'},
        ),
        migrations.AlterModelOptions(
            name='wydawnictwo_zwarte',
            options={'verbose_name': 'wydawnictwo zwarte', 'verbose_name_plural': 'wydawnictwa zwarte'},
        ),
        migrations.AlterField(
            model_name='autor',
            name='adnotacje',
            field=models.TextField(blank=True, db_index=True, help_text='Pole do użytku wewnętrznego -\n    wpisane tu informacje nie są wyświetlane na stronach WWW dostępnych\n    dla użytkowników końcowych.', null=True),
        ),
        migrations.AlterField(
            model_name='autor',
            name='aktualny',
            field=models.BooleanField(db_index=True, default=False, help_text='Jeżeli zaznaczone, pole to oznacza,\n    że autor jest aktualnie - na dziś dzień - przypisany do jakiejś jednostki w bazie danych i jego przypisanie\n    do tej jednostki nie zostało zakończone wraz z konkretną datą w \n    przeszłości.', verbose_name='Aktualny?'),
        ),
        migrations.AlterField(
            model_name='autor',
            name='email',
            field=models.EmailField(blank=True, max_length=128, null=True, verbose_name='E-mail'),
        ),
        migrations.AlterField(
            model_name='autor',
            name='pbn_id',
            field=models.IntegerField(blank=True, db_index=True, help_text='Identyfikator w systemie Polskiej Bibliografii Naukowej (PBN)', null=True, unique=True, verbose_name='Identyfikator PBN'),
        ),
        migrations.AlterField(
            model_name='autor',
            name='pesel_md5',
            field=models.CharField(blank=True, db_index=True, help_text='Hash MD5 numeru PESEL', max_length=32, null=True, verbose_name='PESEL MD5'),
        ),
        migrations.AlterField(
            model_name='autor',
            name='poprzednie_nazwiska',
            field=models.CharField(blank=True, db_index=True, help_text='Jeżeli ten\n        autor(-ka) posiada nazwisko panieńskie, pod którym ukazywały\n        się publikacje lub zmieniał nazwisko z innych powodów, wpisz tutaj\n        wszystkie poprzednie nazwiska, oddzielając je przecinkami.', max_length=1024, null=True),
        ),
        migrations.AlterField(
            model_name='autor',
            name='slug',
            field=autoslug.fields.AutoSlugField(editable=False, max_length=1024, populate_from='get_full_name', unique=True),
        ),
        migrations.AlterField(
            model_name='autor',
            name='www',
            field=models.URLField(blank=True, max_length=1024, null=True, verbose_name='WWW'),
        ),
        migrations.AlterField(
            model_name='autor_jednostka',
            name='rozpoczal_prace',
            field=models.DateField(blank=True, db_index=True, null=True, verbose_name='Rozpoczął pracę'),
        ),
        migrations.AlterField(
            model_name='autor_jednostka',
            name='zakonczyl_prace',
            field=models.DateField(blank=True, db_index=True, null=True, verbose_name='Zakończył pracę'),
        ),
        migrations.AlterField(
            model_name='bppuser',
            name='adnotacje',
            field=models.TextField(blank=True, db_index=True, help_text='Pole do użytku wewnętrznego -\n    wpisane tu informacje nie są wyświetlane na stronach WWW dostępnych\n    dla użytkowników końcowych.', null=True),
        ),
        migrations.AlterField(
            model_name='bppuser',
            name='multiseek_format',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Ostatnio wybrany format wyświetlania w Multiseeku'),
        ),
        migrations.AlterField(
            model_name='bppuser',
            name='multiseek_order_1',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Ostatnio wybrane pole sortowania w Multiseeku'),
        ),
        migrations.AlterField(
            model_name='bppuser',
            name='per_page',
            field=models.IntegerField(default=20, verbose_name='Ilość wyświetlanych rekordów na stronie'),
        ),
        migrations.AlterField(
            model_name='bppuser',
            name='username',
            field=models.CharField(error_messages={'unique': 'A user with that username already exists.'}, help_text='Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.', max_length=150, unique=True, validators=[django.contrib.auth.validators.UnicodeUsernameValidator()], verbose_name='username'),
        ),
        migrations.AlterField(
            model_name='charakter_formalny',
            name='artykul_pbn',
            field=models.BooleanField(default=False, help_text='Wydawnictwa ciągłe posiadające\n     ten charakter formalny zostaną włączone do eksportu PBN jako artykuły', verbose_name='Artykuł w PBN'),
        ),
        migrations.AlterField(
            model_name='charakter_formalny',
            name='charakter_pbn',
            field=models.ForeignKey(blank=True, default=None, help_text='Wartość wybrana w tym polu zostanie użyta jako zawartość tagu <is>\n                                      w plikach eksportu do PBN', null=True, on_delete=django.db.models.deletion.CASCADE, to='bpp.Charakter_PBN', verbose_name='Charakter PBN'),
        ),
        migrations.AlterField(
            model_name='charakter_formalny',
            name='ksiazka_pbn',
            field=models.BooleanField(default=False, help_text='Wydawnictwa zwarte posiadające ten\n    charakter formalny zostaną włączone do eksportu PBN jako ksiażki', verbose_name='Książka w PBN'),
        ),
        migrations.AlterField(
            model_name='charakter_formalny',
            name='nazwa_w_primo',
            field=models.CharField(blank=True, choices=[('', ''), ('Artykuł', 'Artykuł'), ('Książka', 'Książka'), ('Zasób tekstowy', 'Zasób tekstowy'), ('Rozprawa naukowa', 'Rozprawa naukowa'), ('Recenzja', 'Recenzja'), ('Artykuł prasowy', 'Artykuł prasowy'), ('Rozdział', 'Rozdział'), ('Czasopismo', 'Czasopismo'), ('Dane badawcze', 'Dane badawcze'), ('Materiał konferencyjny', 'Materiał konferencyjny'), ('Obraz', 'Obraz'), ('Baza', 'Baza'), ('Zestaw danych statystycznych', 'Zestaw danych statystycznych'), ('Multimedia', 'Multimedia'), ('Inny', 'Inny')], db_index=True, default='', help_text='\n    Nazwa charakteru formalnego w wyszukiwarce Primo, eksponowana przez OAI-PMH. W przypadku,\n    gdy to pole jest puste, prace o danym charakterze formalnym nie będą udostępniane przez\n    protokół OAI-PMH.\n    ', max_length=100, verbose_name='Nazwa w Primo'),
        ),
        migrations.AlterField(
            model_name='charakter_formalny',
            name='publikacja',
            field=models.BooleanField(default=False, help_text='Jest charakterem dla publikacji'),
        ),
        migrations.AlterField(
            model_name='charakter_formalny',
            name='rozdzial_pbn',
            field=models.BooleanField(default=False, help_text='Wydawnictwa zwarte posiadające ten\n    charakter formalny zostaną włączone do eksportu PBN jako rozdziały', verbose_name='Rozdział w PBN'),
        ),
        migrations.AlterField(
            model_name='charakter_formalny',
            name='streszczenie',
            field=models.BooleanField(default=False, help_text='Jest charakterem dla streszczeń'),
        ),
        migrations.AlterField(
            model_name='charakter_pbn',
            name='wlasciwy_dla',
            field=models.CharField(choices=[('article', 'Artykuł'), ('book', 'Książka'), ('chapter', 'Rozdział')], max_length=20),
        ),
        migrations.AlterField(
            model_name='jednostka',
            name='adnotacje',
            field=models.TextField(blank=True, db_index=True, help_text='Pole do użytku wewnętrznego -\n    wpisane tu informacje nie są wyświetlane na stronach WWW dostępnych\n    dla użytkowników końcowych.', null=True),
        ),
        migrations.AlterField(
            model_name='jednostka',
            name='aktualna',
            field=models.BooleanField(default=False, help_text="Jeżeli dana jednostka wchodzi w struktury wydziału\n    (czyli jej obecność w strukturach wydziału nie została zakończona z określoną datą), to pole to będzie miało\n    wartość 'PRAWDA'."),
        ),
        migrations.AlterField(
            model_name='jednostka',
            name='email',
            field=models.EmailField(blank=True, max_length=128, null=True, verbose_name='E-mail'),
        ),
        migrations.AlterField(
            model_name='jednostka',
            name='pbn_id',
            field=models.IntegerField(blank=True, db_index=True, help_text='Identyfikator w systemie Polskiej Bibliografii Naukowej (PBN)', null=True, unique=True, verbose_name='Identyfikator PBN'),
        ),
        migrations.AlterField(
            model_name='jednostka',
            name='skrot',
            field=models.CharField(max_length=128, unique=True, verbose_name='Skrót'),
        ),
        migrations.AlterField(
            model_name='jednostka',
            name='skupia_pracownikow',
            field=models.BooleanField(default=True, help_text="Ta jednostka skupia osoby będące faktycznymi pracownikami uczelni. Odznacz dla jednostek\n         typu 'Studenci', 'Doktoranci', 'Pracownicy emerytowani' itp.", verbose_name='Skupia pracowników'),
        ),
        migrations.AlterField(
            model_name='jednostka',
            name='slug',
            field=autoslug.fields.AutoSlugField(editable=False, populate_from='nazwa', unique=True),
        ),
        migrations.AlterField(
            model_name='jednostka',
            name='wchodzi_do_raportow',
            field=models.BooleanField(db_index=True, default=True, verbose_name='Wchodzi do raportów'),
        ),
        migrations.AlterField(
            model_name='jednostka',
            name='www',
            field=models.URLField(blank=True, max_length=1024, null=True, verbose_name='WWW'),
        ),
        migrations.AlterField(
            model_name='jednostka',
            name='wydzial',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='bpp.Wydzial', verbose_name='Wydział'),
        ),
        migrations.AlterField(
            model_name='jednostka',
            name='zarzadzaj_automatycznie',
            field=models.BooleanField(default=True, help_text='Jednostka ta będzie dowolnie modyfikowana przez procedury importujace dane z zewnętrznych\n        systemów informatycznych', verbose_name='Zarządzaj automatycznie'),
        ),
        migrations.AlterField(
            model_name='jezyk',
            name='skrot_dla_pbn',
            field=models.CharField(blank=True, help_text='\n    Skrót nazwy języka używany w plikach eksportu do PBN.', max_length=10, verbose_name='Skrót dla PBN'),
        ),
        migrations.AlterField(
            model_name='patent',
            name='adnotacje',
            field=models.TextField(blank=True, db_index=True, help_text='Pole do użytku wewnętrznego -\n    wpisane tu informacje nie są wyświetlane na stronach WWW dostępnych\n    dla użytkowników końcowych.', null=True),
        ),
        migrations.AlterField(
            model_name='patent',
            name='dostep_dnia',
            field=models.DateField(blank=True, help_text='Data dostępu do strony WWW.', null=True, verbose_name='Dostęp dnia (płatny dostęp)'),
        ),
        migrations.AlterField(
            model_name='patent',
            name='index_copernicus',
            field=models.DecimalField(db_index=True, decimal_places=2, default=Decimal('0.00'), max_digits=6, verbose_name='Index Copernicus'),
        ),
        migrations.AlterField(
            model_name='patent',
            name='informacje',
            field=models.TextField(blank=True, db_index=True, null=True, verbose_name='Informacje'),
        ),
        migrations.AlterField(
            model_name='patent',
            name='kc_impact_factor',
            field=models.DecimalField(blank=True, db_index=True, decimal_places=2, default=None, help_text='Jeżeli wpiszesz\n        wartość w to pole, to zostanie ona użyta w raporcie dla Komisji\n        Centralnej w punkcie IXa tego raportu.', max_digits=6, null=True, verbose_name='KC: Impact factor'),
        ),
        migrations.AlterField(
            model_name='patent',
            name='kc_index_copernicus',
            field=models.DecimalField(blank=True, decimal_places=2, default=None, help_text='Jeżeli wpiszesz\n        wartość w to pole, to zostanie ona użyta w raporcie dla Komisji\n        Centralnej w punkcie IXa i IXb tego raportu.', max_digits=6, null=True, verbose_name='KC: Index Copernicus'),
        ),
        migrations.AlterField(
            model_name='patent',
            name='kc_punkty_kbn',
            field=models.DecimalField(blank=True, db_index=True, decimal_places=2, default=None, help_text='Jeżeli wpiszesz\n        wartość w to pole, to zostanie ona użyta w raporcie dla Komisji\n        Centralnej w punkcie IXa i IXb tego raportu.', max_digits=6, null=True, verbose_name='KC: Punkty KBN'),
        ),
        migrations.AlterField(
            model_name='patent',
            name='opis_bibliograficzny_cache',
            field=models.TextField(default=''),
        ),
        migrations.AlterField(
            model_name='patent',
            name='opis_bibliograficzny_zapisani_autorzy_cache',
            field=models.TextField(default=''),
        ),
        migrations.AlterField(
            model_name='patent',
            name='public_dostep_dnia',
            field=models.DateField(blank=True, help_text='Data wolnego dostępu do strony WWW.', null=True, verbose_name='Dostęp dnia (wolny dostęp)'),
        ),
        migrations.AlterField(
            model_name='patent',
            name='public_www',
            field=models.URLField(blank=True, max_length=2048, null=True, verbose_name='Adres WWW (wolny dostęp)'),
        ),
        migrations.AlterField(
            model_name='patent',
            name='punktacja_wewnetrzna',
            field=models.DecimalField(db_index=True, decimal_places=2, default=Decimal('0.00'), max_digits=6, verbose_name='Punktacja wewnętrzna'),
        ),
        migrations.AlterField(
            model_name='patent',
            name='punkty_kbn',
            field=models.DecimalField(db_index=True, decimal_places=2, default=Decimal('0.00'), max_digits=6, verbose_name='Punkty KBN'),
        ),
        migrations.AlterField(
            model_name='patent',
            name='rok',
            field=models.IntegerField(db_index=True, help_text='Rok uwzględniany przy wyszukiwaniu i raportach\n        KBN/MNiSW)'),
        ),
        migrations.AlterField(
            model_name='patent',
            name='slowa_kluczowe',
            field=models.TextField(blank=True, null=True, verbose_name='Słowa kluczowe'),
        ),
        migrations.AlterField(
            model_name='patent',
            name='szczegoly',
            field=models.CharField(blank=True, help_text='Np. str. 23-45', max_length=512, null=True, verbose_name='Szczegóły'),
        ),
        migrations.AlterField(
            model_name='patent',
            name='tytul_oryginalny',
            field=models.TextField(db_index=True, verbose_name='Tytuł oryginalny'),
        ),
        migrations.AlterField(
            model_name='patent',
            name='tytul_oryginalny_sort',
            field=models.TextField(db_index=True, default=''),
        ),
        migrations.AlterField(
            model_name='patent',
            name='utworzono',
            field=models.DateTimeField(auto_now_add=True, null=True, verbose_name='Utworzono'),
        ),
        migrations.AlterField(
            model_name='patent',
            name='www',
            field=models.URLField(blank=True, max_length=1024, null=True, verbose_name='Adres WWW (płatny dostęp)'),
        ),
        migrations.AlterField(
            model_name='patent_autor',
            name='kolejnosc',
            field=models.IntegerField(default=0, verbose_name='Kolejność'),
        ),
        migrations.AlterField(
            model_name='patent_autor',
            name='typ_odpowiedzialnosci',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bpp.Typ_Odpowiedzialnosci', verbose_name='Typ odpowiedzialności'),
        ),
        migrations.AlterField(
            model_name='patent_autor',
            name='zatrudniony',
            field=models.BooleanField(default=False, help_text='Pracownik jednostki podanej w afiliacji'),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='adnotacje',
            field=models.TextField(blank=True, db_index=True, help_text='Pole do użytku wewnętrznego -\n    wpisane tu informacje nie są wyświetlane na stronach WWW dostępnych\n    dla użytkowników końcowych.', null=True),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='doi',
            field=bpp.fields.DOIField(blank=True, db_index=True, help_text='Digital Object Identifier (DOI)', max_length=2048, null=True, verbose_name='DOI'),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='dostep_dnia',
            field=models.DateField(blank=True, help_text='Data dostępu do strony WWW.', null=True, verbose_name='Dostęp dnia (płatny dostęp)'),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='e_isbn',
            field=models.CharField(blank=True, db_index=True, max_length=64, null=True, verbose_name='E-ISBN'),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='index_copernicus',
            field=models.DecimalField(db_index=True, decimal_places=2, default=Decimal('0.00'), max_digits=6, verbose_name='Index Copernicus'),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='informacje',
            field=models.TextField(blank=True, db_index=True, null=True, verbose_name='Informacje'),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='isbn',
            field=models.CharField(blank=True, db_index=True, max_length=64, null=True, verbose_name='ISBN'),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='jezyk',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bpp.Jezyk', verbose_name='Język'),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='kc_impact_factor',
            field=models.DecimalField(blank=True, db_index=True, decimal_places=2, default=None, help_text='Jeżeli wpiszesz\n        wartość w to pole, to zostanie ona użyta w raporcie dla Komisji\n        Centralnej w punkcie IXa tego raportu.', max_digits=6, null=True, verbose_name='KC: Impact factor'),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='kc_index_copernicus',
            field=models.DecimalField(blank=True, decimal_places=2, default=None, help_text='Jeżeli wpiszesz\n        wartość w to pole, to zostanie ona użyta w raporcie dla Komisji\n        Centralnej w punkcie IXa i IXb tego raportu.', max_digits=6, null=True, verbose_name='KC: Index Copernicus'),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='kc_punkty_kbn',
            field=models.DecimalField(blank=True, db_index=True, decimal_places=2, default=None, help_text='Jeżeli wpiszesz\n        wartość w to pole, to zostanie ona użyta w raporcie dla Komisji\n        Centralnej w punkcie IXa i IXb tego raportu.', max_digits=6, null=True, verbose_name='KC: Punkty KBN'),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='miejsce_i_rok',
            field=models.CharField(blank=True, help_text='Przykładowo:\n        Warszawa 2012. Wpisz proszę najpierw miejsce potem rok; oddziel\n        spacją.', max_length=256, null=True),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='opis_bibliograficzny_cache',
            field=models.TextField(default=''),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='opis_bibliograficzny_zapisani_autorzy_cache',
            field=models.TextField(default=''),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='public_dostep_dnia',
            field=models.DateField(blank=True, help_text='Data wolnego dostępu do strony WWW.', null=True, verbose_name='Dostęp dnia (wolny dostęp)'),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='public_www',
            field=models.URLField(blank=True, max_length=2048, null=True, verbose_name='Adres WWW (wolny dostęp)'),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='pubmed_id',
            field=models.BigIntegerField(blank=True, help_text='Identyfikator PubMed (PMID)', null=True, verbose_name='PubMed ID'),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='punktacja_wewnetrzna',
            field=models.DecimalField(db_index=True, decimal_places=2, default=Decimal('0.00'), max_digits=6, verbose_name='Punktacja wewnętrzna'),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='punkty_kbn',
            field=models.DecimalField(db_index=True, decimal_places=2, default=Decimal('0.00'), max_digits=6, verbose_name='Punkty KBN'),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='rok',
            field=models.IntegerField(db_index=True, help_text='Rok uwzględniany przy wyszukiwaniu i raportach\n        KBN/MNiSW)'),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='slowa_kluczowe',
            field=models.TextField(blank=True, null=True, verbose_name='Słowa kluczowe'),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='szczegoly',
            field=models.CharField(blank=True, help_text='Np. str. 23-45', max_length=512, null=True, verbose_name='Szczegóły'),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='typ_kbn',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bpp.Typ_KBN', verbose_name='Typ KBN'),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='tytul',
            field=models.TextField(blank=True, db_index=True, null=True, verbose_name='Tytuł'),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='tytul_oryginalny',
            field=models.TextField(db_index=True, verbose_name='Tytuł oryginalny'),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='tytul_oryginalny_sort',
            field=models.TextField(db_index=True, default=''),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='utworzono',
            field=models.DateTimeField(auto_now_add=True, null=True, verbose_name='Utworzono'),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='www',
            field=models.URLField(blank=True, max_length=1024, null=True, verbose_name='Adres WWW (płatny dostęp)'),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='adnotacje',
            field=models.TextField(blank=True, db_index=True, help_text='Pole do użytku wewnętrznego -\n    wpisane tu informacje nie są wyświetlane na stronach WWW dostępnych\n    dla użytkowników końcowych.', null=True),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='doi',
            field=bpp.fields.DOIField(blank=True, db_index=True, help_text='Digital Object Identifier (DOI)', max_length=2048, null=True, verbose_name='DOI'),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='dostep_dnia',
            field=models.DateField(blank=True, help_text='Data dostępu do strony WWW.', null=True, verbose_name='Dostęp dnia (płatny dostęp)'),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='e_isbn',
            field=models.CharField(blank=True, db_index=True, max_length=64, null=True, verbose_name='E-ISBN'),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='index_copernicus',
            field=models.DecimalField(db_index=True, decimal_places=2, default=Decimal('0.00'), max_digits=6, verbose_name='Index Copernicus'),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='informacje',
            field=models.TextField(blank=True, db_index=True, null=True, verbose_name='Informacje'),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='isbn',
            field=models.CharField(blank=True, db_index=True, max_length=64, null=True, verbose_name='ISBN'),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='jezyk',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bpp.Jezyk', verbose_name='Język'),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='kc_impact_factor',
            field=models.DecimalField(blank=True, db_index=True, decimal_places=2, default=None, help_text='Jeżeli wpiszesz\n        wartość w to pole, to zostanie ona użyta w raporcie dla Komisji\n        Centralnej w punkcie IXa tego raportu.', max_digits=6, null=True, verbose_name='KC: Impact factor'),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='kc_index_copernicus',
            field=models.DecimalField(blank=True, decimal_places=2, default=None, help_text='Jeżeli wpiszesz\n        wartość w to pole, to zostanie ona użyta w raporcie dla Komisji\n        Centralnej w punkcie IXa i IXb tego raportu.', max_digits=6, null=True, verbose_name='KC: Index Copernicus'),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='kc_punkty_kbn',
            field=models.DecimalField(blank=True, db_index=True, decimal_places=2, default=None, help_text='Jeżeli wpiszesz\n        wartość w to pole, to zostanie ona użyta w raporcie dla Komisji\n        Centralnej w punkcie IXa i IXb tego raportu.', max_digits=6, null=True, verbose_name='KC: Punkty KBN'),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='miejsce_i_rok',
            field=models.CharField(blank=True, help_text='Przykładowo:\n        Warszawa 2012. Wpisz proszę najpierw miejsce potem rok; oddziel\n        spacją.', max_length=256, null=True),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='opis_bibliograficzny_cache',
            field=models.TextField(default=''),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='opis_bibliograficzny_zapisani_autorzy_cache',
            field=models.TextField(default=''),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='public_dostep_dnia',
            field=models.DateField(blank=True, help_text='Data wolnego dostępu do strony WWW.', null=True, verbose_name='Dostęp dnia (wolny dostęp)'),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='public_www',
            field=models.URLField(blank=True, max_length=2048, null=True, verbose_name='Adres WWW (wolny dostęp)'),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='pubmed_id',
            field=models.BigIntegerField(blank=True, help_text='Identyfikator PubMed (PMID)', null=True, verbose_name='PubMed ID'),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='punktacja_wewnetrzna',
            field=models.DecimalField(db_index=True, decimal_places=2, default=Decimal('0.00'), max_digits=6, verbose_name='Punktacja wewnętrzna'),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='punkty_kbn',
            field=models.DecimalField(db_index=True, decimal_places=2, default=Decimal('0.00'), max_digits=6, verbose_name='Punkty KBN'),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='rok',
            field=models.IntegerField(db_index=True, help_text='Rok uwzględniany przy wyszukiwaniu i raportach\n        KBN/MNiSW)'),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='slowa_kluczowe',
            field=models.TextField(blank=True, null=True, verbose_name='Słowa kluczowe'),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='szczegoly',
            field=models.CharField(blank=True, help_text='Np. str. 23-45', max_length=512, null=True, verbose_name='Szczegóły'),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='typ_kbn',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bpp.Typ_KBN', verbose_name='Typ KBN'),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='tytul',
            field=models.TextField(blank=True, db_index=True, null=True, verbose_name='Tytuł'),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='tytul_oryginalny',
            field=models.TextField(db_index=True, verbose_name='Tytuł oryginalny'),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='tytul_oryginalny_sort',
            field=models.TextField(db_index=True, default=''),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='utworzono',
            field=models.DateTimeField(auto_now_add=True, null=True, verbose_name='Utworzono'),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='www',
            field=models.URLField(blank=True, max_length=1024, null=True, verbose_name='Adres WWW (płatny dostęp)'),
        ),
        migrations.AlterField(
            model_name='publikacja_habilitacyjna',
            name='kolejnosc',
            field=models.IntegerField(default=0, verbose_name='Kolejność'),
        ),
        migrations.AlterField(
            model_name='punktacja_zrodla',
            name='index_copernicus',
            field=models.DecimalField(db_index=True, decimal_places=2, default=Decimal('0.00'), max_digits=6, verbose_name='Index Copernicus'),
        ),
        migrations.AlterField(
            model_name='punktacja_zrodla',
            name='kc_impact_factor',
            field=models.DecimalField(blank=True, db_index=True, decimal_places=2, default=None, help_text='Jeżeli wpiszesz\n        wartość w to pole, to zostanie ona użyta w raporcie dla Komisji\n        Centralnej w punkcie IXa tego raportu.', max_digits=6, null=True, verbose_name='KC: Impact factor'),
        ),
        migrations.AlterField(
            model_name='punktacja_zrodla',
            name='kc_index_copernicus',
            field=models.DecimalField(blank=True, decimal_places=2, default=None, help_text='Jeżeli wpiszesz\n        wartość w to pole, to zostanie ona użyta w raporcie dla Komisji\n        Centralnej w punkcie IXa i IXb tego raportu.', max_digits=6, null=True, verbose_name='KC: Index Copernicus'),
        ),
        migrations.AlterField(
            model_name='punktacja_zrodla',
            name='kc_punkty_kbn',
            field=models.DecimalField(blank=True, db_index=True, decimal_places=2, default=None, help_text='Jeżeli wpiszesz\n        wartość w to pole, to zostanie ona użyta w raporcie dla Komisji\n        Centralnej w punkcie IXa i IXb tego raportu.', max_digits=6, null=True, verbose_name='KC: Punkty KBN'),
        ),
        migrations.AlterField(
            model_name='punktacja_zrodla',
            name='punktacja_wewnetrzna',
            field=models.DecimalField(db_index=True, decimal_places=2, default=Decimal('0.00'), max_digits=6, verbose_name='Punktacja wewnętrzna'),
        ),
        migrations.AlterField(
            model_name='punktacja_zrodla',
            name='punkty_kbn',
            field=models.DecimalField(db_index=True, decimal_places=2, default=Decimal('0.00'), max_digits=6, verbose_name='Punkty KBN'),
        ),
        migrations.AlterField(
            model_name='typ_kbn',
            name='artykul_pbn',
            field=models.BooleanField(default=False, help_text='Wydawnictwa ciągłe posiadające\n    ten typ KBN zostaną włączone do eksportu PBN jako artykuły', verbose_name='Artykuł w PBN'),
        ),
        migrations.AlterField(
            model_name='uczelnia',
            name='adnotacje',
            field=models.TextField(blank=True, db_index=True, help_text='Pole do użytku wewnętrznego -\n    wpisane tu informacje nie są wyświetlane na stronach WWW dostępnych\n    dla użytkowników końcowych.', null=True),
        ),
        migrations.AlterField(
            model_name='uczelnia',
            name='favicon_ico',
            field=models.FileField(blank=True, null=True, upload_to='favicon', verbose_name='Ikona ulubionych (favicon)'),
        ),
        migrations.AlterField(
            model_name='uczelnia',
            name='logo_svg',
            field=models.FileField(blank=True, null=True, upload_to='logo_svg', verbose_name='Logo wektorowe (SVG)'),
        ),
        migrations.AlterField(
            model_name='uczelnia',
            name='logo_www',
            field=models.ImageField(blank=True, help_text='Plik w formacie bitmapowym, np. JPEG lub PNG,\n        w rozdzielczości maks. 100x100', null=True, upload_to='logo', verbose_name='Logo na stronę WWW'),
        ),
        migrations.AlterField(
            model_name='uczelnia',
            name='obca_jednostka',
            field=models.ForeignKey(blank=True, help_text='\n    Jednostka skupiająca autorów nieindeksowanych, nie będących pracownikami uczelni. Procedury importujące\n    dane z zewnętrznych systemów informatycznych będą przypisywać do tej jednostki osoby, które zakończyły\n    pracę na uczelni. ', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='obca_jednostka', to='bpp.Jednostka'),
        ),
        migrations.AlterField(
            model_name='uczelnia',
            name='pbn_id',
            field=models.IntegerField(blank=True, db_index=True, help_text='Identyfikator w systemie Polskiej Bibliografii Naukowej (PBN)', null=True, unique=True, verbose_name='Identyfikator PBN'),
        ),
        migrations.AlterField(
            model_name='uczelnia',
            name='slug',
            field=autoslug.fields.AutoSlugField(editable=False, populate_from='skrot', unique=True),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='adnotacje',
            field=models.TextField(blank=True, db_index=True, help_text='Pole do użytku wewnętrznego -\n    wpisane tu informacje nie są wyświetlane na stronach WWW dostępnych\n    dla użytkowników końcowych.', null=True),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='charakter_formalny',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bpp.Charakter_Formalny', verbose_name='Charakter formalny'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='doi',
            field=bpp.fields.DOIField(blank=True, db_index=True, help_text='Digital Object Identifier (DOI)', max_length=2048, null=True, verbose_name='DOI'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='dostep_dnia',
            field=models.DateField(blank=True, help_text='Data dostępu do strony WWW.', null=True, verbose_name='Dostęp dnia (płatny dostęp)'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='e_issn',
            field=models.CharField(blank=True, max_length=32, null=True, verbose_name='e-ISSN'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='index_copernicus',
            field=models.DecimalField(db_index=True, decimal_places=2, default=Decimal('0.00'), max_digits=6, verbose_name='Index Copernicus'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='informacje',
            field=models.TextField(blank=True, db_index=True, null=True, verbose_name='Informacje'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='issn',
            field=models.CharField(blank=True, max_length=32, null=True, verbose_name='ISSN'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='jezyk',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bpp.Jezyk', verbose_name='Język'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='kc_impact_factor',
            field=models.DecimalField(blank=True, db_index=True, decimal_places=2, default=None, help_text='Jeżeli wpiszesz\n        wartość w to pole, to zostanie ona użyta w raporcie dla Komisji\n        Centralnej w punkcie IXa tego raportu.', max_digits=6, null=True, verbose_name='KC: Impact factor'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='kc_index_copernicus',
            field=models.DecimalField(blank=True, decimal_places=2, default=None, help_text='Jeżeli wpiszesz\n        wartość w to pole, to zostanie ona użyta w raporcie dla Komisji\n        Centralnej w punkcie IXa i IXb tego raportu.', max_digits=6, null=True, verbose_name='KC: Index Copernicus'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='kc_punkty_kbn',
            field=models.DecimalField(blank=True, db_index=True, decimal_places=2, default=None, help_text='Jeżeli wpiszesz\n        wartość w to pole, to zostanie ona użyta w raporcie dla Komisji\n        Centralnej w punkcie IXa i IXb tego raportu.', max_digits=6, null=True, verbose_name='KC: Punkty KBN'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='liczba_znakow_wydawniczych',
            field=models.IntegerField(blank=True, db_index=True, null=True, verbose_name='Liczba znaków wydawniczych'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='openaccess_czas_publikacji',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='bpp.Czas_Udostepnienia_OpenAccess', verbose_name='OpenAccess: czas udostępnienia'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='openaccess_ilosc_miesiecy',
            field=models.PositiveIntegerField(blank=True, help_text='Ilość miesięcy jakie upłynęły od momentu opublikowania do momentu udostępnienia', null=True, verbose_name='OpenAccess: ilość miesięcy'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='openaccess_licencja',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='bpp.Licencja_OpenAccess', verbose_name='OpenAccess: licencja'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='openaccess_tryb_dostepu',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='bpp.Tryb_OpenAccess_Wydawnictwo_Ciagle', verbose_name='OpenAccess: tryb dostępu'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='openaccess_wersja_tekstu',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='bpp.Wersja_Tekstu_OpenAccess', verbose_name='OpenAccess: wersja tekstu'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='opis_bibliograficzny_cache',
            field=models.TextField(default=''),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='opis_bibliograficzny_zapisani_autorzy_cache',
            field=models.TextField(default=''),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='ostatnio_zmieniony_dla_pbn',
            field=models.DateTimeField(auto_now_add=True, help_text='Moment ostatniej aktualizacji rekordu dla potrzeb PBN. To pole zmieni się automatycznie, gdy\n        nastąpi zmiana dowolnego z pól za wyjątkiem bloków pól: „punktacja”, „punktacja komisji centralnej”,\n        „adnotacje” oraz pole „status korekty”.', verbose_name='Ostatnio zmieniony (dla PBN)'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='public_dostep_dnia',
            field=models.DateField(blank=True, help_text='Data wolnego dostępu do strony WWW.', null=True, verbose_name='Dostęp dnia (wolny dostęp)'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='public_www',
            field=models.URLField(blank=True, max_length=2048, null=True, verbose_name='Adres WWW (wolny dostęp)'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='pubmed_id',
            field=models.BigIntegerField(blank=True, help_text='Identyfikator PubMed (PMID)', null=True, verbose_name='PubMed ID'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='punktacja_wewnetrzna',
            field=models.DecimalField(db_index=True, decimal_places=2, default=Decimal('0.00'), max_digits=6, verbose_name='Punktacja wewnętrzna'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='punkty_kbn',
            field=models.DecimalField(db_index=True, decimal_places=2, default=Decimal('0.00'), max_digits=6, verbose_name='Punkty KBN'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='rok',
            field=models.IntegerField(db_index=True, help_text='Rok uwzględniany przy wyszukiwaniu i raportach\n        KBN/MNiSW)'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='slowa_kluczowe',
            field=models.TextField(blank=True, null=True, verbose_name='Słowa kluczowe'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='szczegoly',
            field=models.CharField(blank=True, help_text='Np. str. 23-45', max_length=512, null=True, verbose_name='Szczegóły'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='typ_kbn',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bpp.Typ_KBN', verbose_name='Typ KBN'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='tytul',
            field=models.TextField(blank=True, db_index=True, null=True, verbose_name='Tytuł'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='tytul_oryginalny',
            field=models.TextField(db_index=True, verbose_name='Tytuł oryginalny'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='tytul_oryginalny_sort',
            field=models.TextField(db_index=True, default=''),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='utworzono',
            field=models.DateTimeField(auto_now_add=True, null=True, verbose_name='Utworzono'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='www',
            field=models.URLField(blank=True, max_length=1024, null=True, verbose_name='Adres WWW (płatny dostęp)'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='zrodlo',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='bpp.Zrodlo', verbose_name='Źródło'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle_autor',
            name='kolejnosc',
            field=models.IntegerField(default=0, verbose_name='Kolejność'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle_autor',
            name='typ_odpowiedzialnosci',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bpp.Typ_Odpowiedzialnosci', verbose_name='Typ odpowiedzialności'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle_autor',
            name='zatrudniony',
            field=models.BooleanField(default=False, help_text='Pracownik jednostki podanej w afiliacji'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='adnotacje',
            field=models.TextField(blank=True, db_index=True, help_text='Pole do użytku wewnętrznego -\n    wpisane tu informacje nie są wyświetlane na stronach WWW dostępnych\n    dla użytkowników końcowych.', null=True),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='calkowita_liczba_autorow',
            field=models.PositiveIntegerField(blank=True, help_text='Jeżeli dodajesz monografię, wpisz tutaj całkowitą liczbę\n        autorów monografii. Ta informacja zostanie użyta w eksporcie danych do PBN.', null=True),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='charakter_formalny',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bpp.Charakter_Formalny', verbose_name='Charakter formalny'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='doi',
            field=bpp.fields.DOIField(blank=True, db_index=True, help_text='Digital Object Identifier (DOI)', max_length=2048, null=True, verbose_name='DOI'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='dostep_dnia',
            field=models.DateField(blank=True, help_text='Data dostępu do strony WWW.', null=True, verbose_name='Dostęp dnia (płatny dostęp)'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='e_isbn',
            field=models.CharField(blank=True, db_index=True, max_length=64, null=True, verbose_name='E-ISBN'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='index_copernicus',
            field=models.DecimalField(db_index=True, decimal_places=2, default=Decimal('0.00'), max_digits=6, verbose_name='Index Copernicus'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='informacje',
            field=models.TextField(blank=True, db_index=True, null=True, verbose_name='Informacje'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='isbn',
            field=models.CharField(blank=True, db_index=True, max_length=64, null=True, verbose_name='ISBN'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='jezyk',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bpp.Jezyk', verbose_name='Język'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='kc_impact_factor',
            field=models.DecimalField(blank=True, db_index=True, decimal_places=2, default=None, help_text='Jeżeli wpiszesz\n        wartość w to pole, to zostanie ona użyta w raporcie dla Komisji\n        Centralnej w punkcie IXa tego raportu.', max_digits=6, null=True, verbose_name='KC: Impact factor'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='kc_index_copernicus',
            field=models.DecimalField(blank=True, decimal_places=2, default=None, help_text='Jeżeli wpiszesz\n        wartość w to pole, to zostanie ona użyta w raporcie dla Komisji\n        Centralnej w punkcie IXa i IXb tego raportu.', max_digits=6, null=True, verbose_name='KC: Index Copernicus'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='kc_punkty_kbn',
            field=models.DecimalField(blank=True, db_index=True, decimal_places=2, default=None, help_text='Jeżeli wpiszesz\n        wartość w to pole, to zostanie ona użyta w raporcie dla Komisji\n        Centralnej w punkcie IXa i IXb tego raportu.', max_digits=6, null=True, verbose_name='KC: Punkty KBN'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='liczba_znakow_wydawniczych',
            field=models.IntegerField(blank=True, db_index=True, null=True, verbose_name='Liczba znaków wydawniczych'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='miejsce_i_rok',
            field=models.CharField(blank=True, help_text='Przykładowo:\n        Warszawa 2012. Wpisz proszę najpierw miejsce potem rok; oddziel\n        spacją.', max_length=256, null=True),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='openaccess_czas_publikacji',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='bpp.Czas_Udostepnienia_OpenAccess', verbose_name='OpenAccess: czas udostępnienia'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='openaccess_ilosc_miesiecy',
            field=models.PositiveIntegerField(blank=True, help_text='Ilość miesięcy jakie upłynęły od momentu opublikowania do momentu udostępnienia', null=True, verbose_name='OpenAccess: ilość miesięcy'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='openaccess_licencja',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='bpp.Licencja_OpenAccess', verbose_name='OpenAccess: licencja'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='openaccess_wersja_tekstu',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='bpp.Wersja_Tekstu_OpenAccess', verbose_name='OpenAccess: wersja tekstu'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='opis_bibliograficzny_cache',
            field=models.TextField(default=''),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='opis_bibliograficzny_zapisani_autorzy_cache',
            field=models.TextField(default=''),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='ostatnio_zmieniony_dla_pbn',
            field=models.DateTimeField(auto_now_add=True, help_text='Moment ostatniej aktualizacji rekordu dla potrzeb PBN. To pole zmieni się automatycznie, gdy\n        nastąpi zmiana dowolnego z pól za wyjątkiem bloków pól: „punktacja”, „punktacja komisji centralnej”,\n        „adnotacje” oraz pole „status korekty”.', verbose_name='Ostatnio zmieniony (dla PBN)'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='public_dostep_dnia',
            field=models.DateField(blank=True, help_text='Data wolnego dostępu do strony WWW.', null=True, verbose_name='Dostęp dnia (wolny dostęp)'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='public_www',
            field=models.URLField(blank=True, max_length=2048, null=True, verbose_name='Adres WWW (wolny dostęp)'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='pubmed_id',
            field=models.BigIntegerField(blank=True, help_text='Identyfikator PubMed (PMID)', null=True, verbose_name='PubMed ID'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='punktacja_wewnetrzna',
            field=models.DecimalField(db_index=True, decimal_places=2, default=Decimal('0.00'), max_digits=6, verbose_name='Punktacja wewnętrzna'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='punkty_kbn',
            field=models.DecimalField(db_index=True, decimal_places=2, default=Decimal('0.00'), max_digits=6, verbose_name='Punkty KBN'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='rok',
            field=models.IntegerField(db_index=True, help_text='Rok uwzględniany przy wyszukiwaniu i raportach\n        KBN/MNiSW)'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='slowa_kluczowe',
            field=models.TextField(blank=True, null=True, verbose_name='Słowa kluczowe'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='szczegoly',
            field=models.CharField(blank=True, help_text='Np. str. 23-45', max_length=512, null=True, verbose_name='Szczegóły'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='typ_kbn',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bpp.Typ_KBN', verbose_name='Typ KBN'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='tytul',
            field=models.TextField(blank=True, db_index=True, null=True, verbose_name='Tytuł'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='tytul_oryginalny',
            field=models.TextField(db_index=True, verbose_name='Tytuł oryginalny'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='tytul_oryginalny_sort',
            field=models.TextField(db_index=True, default=''),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='utworzono',
            field=models.DateTimeField(auto_now_add=True, null=True, verbose_name='Utworzono'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='www',
            field=models.URLField(blank=True, max_length=1024, null=True, verbose_name='Adres WWW (płatny dostęp)'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='wydawnictwo_nadrzedne',
            field=models.ForeignKey(blank=True, help_text='Jeżeli dodajesz rozdział,\n        tu wybierz pracę, w ramach której dany rozdział występuje.', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='wydawnictwa_powiazane_set', to='bpp.Wydawnictwo_Zwarte'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte_autor',
            name='kolejnosc',
            field=models.IntegerField(default=0, verbose_name='Kolejność'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte_autor',
            name='typ_odpowiedzialnosci',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bpp.Typ_Odpowiedzialnosci', verbose_name='Typ odpowiedzialności'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte_autor',
            name='zatrudniony',
            field=models.BooleanField(default=False, help_text='Pracownik jednostki podanej w afiliacji'),
        ),
        migrations.AlterField(
            model_name='wydzial',
            name='adnotacje',
            field=models.TextField(blank=True, db_index=True, help_text='Pole do użytku wewnętrznego -\n    wpisane tu informacje nie są wyświetlane na stronach WWW dostępnych\n    dla użytkowników końcowych.', null=True),
        ),
        migrations.AlterField(
            model_name='wydzial',
            name='kolejnosc',
            field=models.IntegerField(default=0, verbose_name='Kolejność'),
        ),
        migrations.AlterField(
            model_name='wydzial',
            name='nazwa',
            field=models.CharField(help_text='Pełna nazwa wydziału, np. "Wydział Lekarski"', max_length=512, unique=True),
        ),
        migrations.AlterField(
            model_name='wydzial',
            name='otwarcie',
            field=models.DateField(blank=True, null=True, verbose_name='Data otwarcia wydziału'),
        ),
        migrations.AlterField(
            model_name='wydzial',
            name='pbn_id',
            field=models.IntegerField(blank=True, db_index=True, help_text='Identyfikator w systemie Polskiej Bibliografii Naukowej (PBN)', null=True, unique=True, verbose_name='Identyfikator PBN'),
        ),
        migrations.AlterField(
            model_name='wydzial',
            name='poprzednie_nazwy',
            field=models.CharField(blank=True, default='', max_length=4096, null=True),
        ),
        migrations.AlterField(
            model_name='wydzial',
            name='skrot',
            field=models.CharField(help_text='Skrót nazwy wydziału, wersja minimalna, np. "WL"', max_length=4, unique=True, verbose_name='Skrót'),
        ),
        migrations.AlterField(
            model_name='wydzial',
            name='slug',
            field=autoslug.fields.AutoSlugField(editable=False, max_length=512, populate_from='nazwa', unique=True),
        ),
        migrations.AlterField(
            model_name='wydzial',
            name='widoczny',
            field=models.BooleanField(default=True, help_text='Czy wydział ma być widoczny przy przeglądaniu strony dla zakładki "Uczelnia"?'),
        ),
        migrations.AlterField(
            model_name='wydzial',
            name='zamkniecie',
            field=models.DateField(blank=True, null=True, verbose_name='Data zamknięcia wydziału'),
        ),
        migrations.AlterField(
            model_name='wydzial',
            name='zarzadzaj_automatycznie',
            field=models.BooleanField(default=True, help_text="Wydział ten będzie dowolnie modyfikowany przez procedury importujace dane z zewnętrznych\n        systemów informatycznych. W przypadku, gdy pole ma ustawioną wartość na 'fałsz', wydział ten może być", verbose_name='Zarządzaj automatycznie'),
        ),
        migrations.AlterField(
            model_name='wydzial',
            name='zezwalaj_na_ranking_autorow',
            field=models.BooleanField(default=True, verbose_name='Zezwalaj na generowanie rankingu autorów dla tego wydziału'),
        ),
        migrations.AlterField(
            model_name='zrodlo',
            name='adnotacje',
            field=models.TextField(blank=True, db_index=True, help_text='Pole do użytku wewnętrznego -\n    wpisane tu informacje nie są wyświetlane na stronach WWW dostępnych\n    dla użytkowników końcowych.', null=True),
        ),
        migrations.AlterField(
            model_name='zrodlo',
            name='doi',
            field=bpp.fields.DOIField(blank=True, db_index=True, help_text='Digital Object Identifier (DOI)', max_length=2048, null=True, verbose_name='DOI'),
        ),
        migrations.AlterField(
            model_name='zrodlo',
            name='e_issn',
            field=models.CharField(blank=True, max_length=32, null=True, verbose_name='e-ISSN'),
        ),
        migrations.AlterField(
            model_name='zrodlo',
            name='issn',
            field=models.CharField(blank=True, max_length=32, null=True, verbose_name='ISSN'),
        ),
        migrations.AlterField(
            model_name='zrodlo',
            name='openaccess_licencja',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='bpp.Licencja_OpenAccess', verbose_name='OpenAccess: licencja'),
        ),
        migrations.AlterField(
            model_name='zrodlo',
            name='openaccess_tryb_dostepu',
            field=models.CharField(blank=True, choices=[('FULL', 'pełny'), ('PARTIAL', 'częściowy')], db_index=True, max_length=50, verbose_name='OpenAccess: tryb dostępu'),
        ),
        migrations.AlterField(
            model_name='zrodlo',
            name='poprzednia_nazwa',
            field=models.CharField(blank=True, db_index=True, max_length=1024, null=True, verbose_name='Poprzedni tytuł'),
        ),
        migrations.AlterField(
            model_name='zrodlo',
            name='skrot',
            field=models.CharField(db_index=True, max_length=512, verbose_name='Skrót'),
        ),
        migrations.AlterField(
            model_name='zrodlo',
            name='slug',
            field=autoslug.fields.AutoSlugField(editable=False, populate_from='nazwa', unique=True),
        ),
        migrations.AlterField(
            model_name='zrodlo',
            name='www',
            field=models.URLField(blank=True, db_index=True, max_length=1024, null=True, verbose_name='WWW'),
        ),
    ]



from datetime import date

import pytest
from model_bakery import baker

from bpp.models.struktura import Jednostka, Jednostka_Wydzial, Wydzial


@pytest.mark.django_db
def test_jednostka_publiczna(wydzial, uczelnia):
    j = baker.make(Jednostka, widoczna=True, uczelnia=uczelnia, aktualna=True)
    Jednostka_Wydzial.objects.create(jednostka=j, wydzial=wydzial)
    assert Jednostka.objects.publiczne().count() == 1


@pytest.mark.django_db
def test_jednostka_widoczne():
    j = baker.make(Jednostka, widoczna=True, aktualna=True)
    assert Jednostka.objects.widoczne().count() == 1

    j.widoczna = False
    j.save()
    assert Jednostka.objects.widoczne().count() == 0


@pytest.mark.django_db
def test_jednostka_test_wydzial_dnia_pusty():
    j = baker.make(Jednostka, nazwa="Jednostka")
    w = baker.make(Wydzial, nazwa="Wydzial", uczelnia=j.uczelnia)

    Jednostka_Wydzial.objects.create(jednostka=j, wydzial=w)

    assert j.wydzial_dnia(date(1, 1, 1)) == w
    assert j.wydzial_dnia(date(2030, 1, 1)) == w
    assert j.wydzial_dnia(date(9999, 12, 31)) == w


@pytest.mark.django_db
def test_jednostka_test_wydzial_dnia():
    j = baker.make(Jednostka)
    w = baker.make(Wydzial, uczelnia=j.uczelnia)

    Jednostka_Wydzial.objects.create(
        jednostka=j, wydzial=w, od=date(2015, 1, 1), do=date(2015, 2, 1)
    )

    assert j.wydzial_dnia(date(1, 1, 1)) is None
    assert j.wydzial_dnia(date(2015, 1, 1)) == w
    assert j.wydzial_dnia(date(2015, 1, 2)) == w
    assert j.wydzial_dnia(date(2015, 2, 1)) == w
    assert j.wydzial_dnia(date(2015, 2, 2)) is None


@pytest.mark.django_db
def test_jednostka_test_przypisania_dla_czasokresu():
    j = baker.make(Jednostka)
    w = baker.make(Wydzial, uczelnia=j.uczelnia)
    Jednostka_Wydzial.objects.create(
        jednostka=j, wydzial=w, od=date(2015, 1, 1), do=date(2015, 2, 1)
    )

    ret = j.przypisania_dla_czasokresu(date(2015, 2, 1), date(2015, 2, 20))
    assert ret.count() == 1

    ret = j.przypisania_dla_czasokresu(date(2015, 2, 2), date(2015, 2, 20))
    assert ret.count() == 0

    ret = j.przypisania_dla_czasokresu(date(2014, 12, 1), date(2014, 12, 31))
    assert ret.count() == 0

    ret = j.przypisania_dla_czasokresu(date(2014, 12, 1), date(2015, 1, 1))
    assert ret.count() == 1


@pytest.mark.django_db
def test_jednostka_get_default_ordering(uczelnia):

    assert Jednostka.objects.get_default_ordering() == ("nazwa",)

    uczelnia.sortuj_jednostki_alfabetycznie = True
    uczelnia.save()

    assert Jednostka.objects.get_default_ordering() == ("nazwa",)

    uczelnia.sortuj_jednostki_alfabetycznie = False
    uczelnia.save()

    assert Jednostka.objects.get_default_ordering() == (
        "kolejnosc",
        "nazwa",
    )



# Create your views here.
from datetime import timedelta

from braces.views import GroupRequiredMixin
from denorm.models import DirtyInstance
from django.db import transaction
from django.http import HttpResponseRedirect
from django.views import generic

from ewaluacja2021.forms import ImportMaksymalnychSlotowForm, ZamowienieNaRaportForm
from ewaluacja2021.models import ImportMaksymalnychSlotow, ZamowienieNaRaport
from ewaluacja2021.tasks import generuj_algorytm, suma_odpietych_dyscyplin
from long_running.tasks import perform_generic_long_running_task

from django.utils import timezone

from bpp.const import GR_WPROWADZANIE_DANYCH
from bpp.models import Patent_Autor, Wydawnictwo_Ciagle_Autor, Wydawnictwo_Zwarte_Autor


class NowyImport(GroupRequiredMixin, generic.CreateView):
    group_required = GR_WPROWADZANIE_DANYCH
    model = ImportMaksymalnychSlotow
    form_class = ImportMaksymalnychSlotowForm

    def form_valid(self, form):
        self.object = form.save()
        transaction.on_commit(
            lambda: perform_generic_long_running_task.delay(
                "ewaluacja2021", "ImportMaksymalnychSlotow".lower(), self.object.pk
            )
        )
        return HttpResponseRedirect(self.get_success_url())


class SzczegolyImportu(GroupRequiredMixin, generic.DetailView):
    group_required = GR_WPROWADZANIE_DANYCH
    model = ImportMaksymalnychSlotow


class ListaImportow(GroupRequiredMixin, generic.ListView):
    group_required = GR_WPROWADZANIE_DANYCH
    model = ImportMaksymalnychSlotow


class NowyRaport3N(GroupRequiredMixin, generic.CreateView):
    group_required = GR_WPROWADZANIE_DANYCH
    model = ZamowienieNaRaport
    form_class = ZamowienieNaRaportForm

    def form_valid(self, form):
        self.object = form.save()
        transaction.on_commit(lambda pk=self.object.pk: generuj_algorytm.delay(pk))
        return HttpResponseRedirect(self.get_success_url())


class SzczegolyRaportu3N(GroupRequiredMixin, generic.DetailView):
    group_required = GR_WPROWADZANIE_DANYCH
    model = ZamowienieNaRaport


class ListaRaporto3N(GroupRequiredMixin, generic.ListView):
    group_required = GR_WPROWADZANIE_DANYCH
    model = ZamowienieNaRaport

    def get(self, request, *args, **kwargs):

        if request.GET.get("resetuj") == "1" and request.user.is_staff:
            with transaction.atomic():
                for klass in (
                    Wydawnictwo_Ciagle_Autor,
                    Wydawnictwo_Zwarte_Autor,
                    Patent_Autor,
                ):
                    klass.objects.exclude(dyscyplina_naukowa=None).filter(
                        przypieta=False
                    ).update(przypieta=True)

            return HttpResponseRedirect(".")

        tydzien_temu = timezone.now() - timedelta(days=5)
        ZamowienieNaRaport.objects.filter(
            ostatnio_zmodyfikowany__lte=tydzien_temu
        ).delete()

        return super().get(request, *args, **kwargs)

    def get_context_data(self, *, object_list=None, **kwargs):
        return super().get_context_data(
            object_list=object_list,
            ilosc_odpietych_dyscyplin=suma_odpietych_dyscyplin(),
            ilosc_elementow_w_kolejce=DirtyInstance.objects.count(),
            **kwargs,
        )


class PlikRaportu3N(GroupRequiredMixin, generic.DetailView):
    group_required = GR_WPROWADZANIE_DANYCH
    model = ZamowienieNaRaport

    def get(self, request, *args, **kw):
        from sendfile import sendfile

        self.object = self.get_object()
        return sendfile(
            request,
            self.object.plik_wyjsciowy.path,
            attachment=True,
            attachment_filename=self.object.plik_wyjsciowy.name,
        )


class WykresRaportu3N(GroupRequiredMixin, generic.DetailView):
    group_required = GR_WPROWADZANIE_DANYCH
    model = ZamowienieNaRaport

    def get(self, request, *args, **kw):
        from sendfile import sendfile

        self.object = self.get_object()
        return sendfile(
            request,
            self.object.wykres_wyjsciowy.path,
            attachment=True,
            attachment_filename=self.object.wykres_wyjsciowy.name,
        )



# -*- coding: utf-8 -*-
# Generated by Django 1.11.8 on 2018-01-01 19:17
from __future__ import unicode_literals

from django.db import migrations
import model_utils.fields


class Migration(migrations.Migration):

    dependencies = [
        ('miniblog', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='article',
            name='article_body',
            field=model_utils.fields.SplitField(help_text='Użyj znacznika podziału „&lt;!-- tutaj --&gt;” w przypadku jeżeli chcesz wyświetlić krótszą wersję treści artykułu', no_excerpt_field=True, verbose_name='Article body'),
        ),
    ]



import pytest
from django import forms

from formdefaults import core
from formdefaults.models import FormRepresentation
from formdefaults.util import full_name


class TestForm(forms.Form):
    fld = forms.CharField(label="Takietam", initial=123)


@pytest.fixture
def test_form():
    return TestForm()


@pytest.fixture
def test_form_repr(test_form):
    return FormRepresentation.objects.get_or_create(full_name=full_name(test_form))[0]


@pytest.mark.django_db
def test_update_form_db_repr(test_form, test_form_repr, normal_django_user):
    core.update_form_db_repr(test_form, test_form_repr)
    assert test_form_repr.fields_set.count() == 1
    assert test_form_repr.values_set.count() == 1

    core.update_form_db_repr(test_form, test_form_repr, user=normal_django_user)
    assert test_form_repr.fields_set.count() == 1
    assert test_form_repr.values_set.count() == 2


@pytest.mark.django_db
def test_get_form_defaults(test_form):

    res = core.get_form_defaults(test_form)
    assert res["fld"] == 123


@pytest.mark.django_db
def test_get_form_defaults_change_label_form(test_form):
    core.get_form_defaults(test_form, "123")

    core.get_form_defaults(test_form, "456")

    assert FormRepresentation.objects.first().label == "456"


@pytest.mark.django_db
def test_get_form_defaults_change_label_field(test_form, test_form_repr):
    core.get_form_defaults(test_form, "123")
    test_form.fields["fld"].label = "456"

    core.get_form_defaults(test_form, "123")

    assert test_form_repr.fields_set.first().label == "456"


@pytest.mark.django_db
def test_get_form_defaults_undumpable_json(test_form, test_form_repr):
    core.get_form_defaults(test_form, "123")
    assert test_form_repr.fields_set.count() == 1
    assert test_form_repr.values_set.first().value == 123

    test_form.fields["fld"].initial = test_get_form_defaults_undumpable_json
    core.get_form_defaults(test_form, "123")
    assert test_form_repr.values_set.count() == 0


@pytest.mark.django_db
def test_get_form_defaults_with_user(test_form, test_form_repr, normal_django_user):

    res = core.get_form_defaults(test_form, user=normal_django_user)
    assert res["fld"] == 123

    db_field = test_form_repr.fields_set.first()

    o = test_form_repr.values_set.first()
    o.value = 456
    o.save()

    res = core.get_form_defaults(test_form, user=normal_django_user)
    assert res["fld"] == 456

    test_form_repr.values_set.create(
        parent=o.parent, field=db_field, user=normal_django_user, value=786
    )

    res = core.get_form_defaults(test_form, user=normal_django_user)
    assert res["fld"] == 786



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-07-17 10:15
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0084_strona_tom_nr_zeszytu'),
    ]

    operations = [
        migrations.AlterField(
            model_name='patent',
            name='strony',
            field=models.CharField(blank=True, help_text='Jeżeli uzupełnione, to pole będzie eksportowane do \n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z \n        pola "Szczegóły" w chwili generowania eksportu PBN. Aby uniknąć \n        sytuacji, gdy wskutek błędnego wprowadzenia tekstu do pola \n        "Szczegóły" informacja ta nie będzie mogła być wyekstrahowana \n        z tego pola, kliknij przycisk "Uzupełnij", aby spowodować uzupełnienie \n        tego pola na podstawie pola "Szczegóły". \n        ', max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='strony',
            field=models.CharField(blank=True, help_text='Jeżeli uzupełnione, to pole będzie eksportowane do \n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z \n        pola "Szczegóły" w chwili generowania eksportu PBN. Aby uniknąć \n        sytuacji, gdy wskutek błędnego wprowadzenia tekstu do pola \n        "Szczegóły" informacja ta nie będzie mogła być wyekstrahowana \n        z tego pola, kliknij przycisk "Uzupełnij", aby spowodować uzupełnienie \n        tego pola na podstawie pola "Szczegóły". \n        ', max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='strony',
            field=models.CharField(blank=True, help_text='Jeżeli uzupełnione, to pole będzie eksportowane do \n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z \n        pola "Szczegóły" w chwili generowania eksportu PBN. Aby uniknąć \n        sytuacji, gdy wskutek błędnego wprowadzenia tekstu do pola \n        "Szczegóły" informacja ta nie będzie mogła być wyekstrahowana \n        z tego pola, kliknij przycisk "Uzupełnij", aby spowodować uzupełnienie \n        tego pola na podstawie pola "Szczegóły". \n        ', max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='strony',
            field=models.CharField(blank=True, help_text='Jeżeli uzupełnione, to pole będzie eksportowane do \n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z \n        pola "Szczegóły" w chwili generowania eksportu PBN. Aby uniknąć \n        sytuacji, gdy wskutek błędnego wprowadzenia tekstu do pola \n        "Szczegóły" informacja ta nie będzie mogła być wyekstrahowana \n        z tego pola, kliknij przycisk "Uzupełnij", aby spowodować uzupełnienie \n        tego pola na podstawie pola "Szczegóły". \n        ', max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='strony',
            field=models.CharField(blank=True, help_text='Jeżeli uzupełnione, to pole będzie eksportowane do \n        danych PBN. Jeżeli puste, informacja ta będzie ekstrahowana z \n        pola "Szczegóły" w chwili generowania eksportu PBN. Aby uniknąć \n        sytuacji, gdy wskutek błędnego wprowadzenia tekstu do pola \n        "Szczegóły" informacja ta nie będzie mogła być wyekstrahowana \n        z tego pola, kliknij przycisk "Uzupełnij", aby spowodować uzupełnienie \n        tego pola na podstawie pola "Szczegóły". \n        ', max_length=50, null=True),
        ),
    ]



def test_Wydawca_search_space_len_24_like_pbn_uid(admin_client):
    url = "/admin/bpp/wydawca/?q=uniwersytet przyrodniczy"
    res = admin_client.get(url, follow=True)
    assert res.status_code == 200


def test_Wydawca_search_no_space_len_24_like_pbn_uid(admin_client):
    url = "/admin/bpp/wydawca/?q=uniwersytet-przyrodniczy"
    res = admin_client.get(url, follow=True)
    assert res.status_code == 200



# Cache'ujemy:
# - Wydawnictwo_Zwarte
# - Wydawnictwo_Ciagle
# - Patent
# - Praca_Doktorska
# - Praca_Habilitacyjna
import denorm
from django.db import connections, models, router
from django.db.models import CASCADE, ForeignKey
from django.db.models.deletion import DO_NOTHING
from taggit.managers import TaggableManager, _TaggableManager
from taggit.models import Tag

from django.contrib.contenttypes.models import ContentType
from django.contrib.postgres.fields.array import ArrayField
from django.contrib.postgres.search import SearchVectorField as VectorField

from django.utils.functional import cached_property

from bpp.models import (
    Autor,
    Dyscyplina_Naukowa,
    Jednostka,
    ModelZDOI,
    ModelZeStatusem,
    ModelZISBN,
    ModelZPBN_UID,
    Typ_Odpowiedzialnosci,
    Wydawnictwo_Zwarte,
    Zrodlo,
)
from bpp.models.abstract import (
    ModelPunktowanyBaza,
    ModelRecenzowany,
    ModelTypowany,
    ModelZCharakterem,
    ModelZeSzczegolami,
    ModelZeZnakamiWydawniczymi,
    ModelZKonferencja,
    ModelZOpenAccess,
    ModelZRokiem,
    ModelZWWW,
)
from bpp.models.util import ModelZOpisemBibliograficznym
from bpp.util import FulltextSearchMixin


class TupleField(ArrayField):
    def from_db_value(self, value, expression, connection):
        return tuple(value)


class AutorzyManager(models.Manager):
    def filter_rekord(self, rekord):
        return self.filter(rekord_id=rekord.pk)


class AutorzyBase(models.Model):
    id = TupleField(models.IntegerField(), size=2, primary_key=True)

    autor = models.ForeignKey("Autor", DO_NOTHING)
    jednostka = models.ForeignKey("Jednostka", DO_NOTHING)
    kolejnosc = models.IntegerField()
    typ_odpowiedzialnosci = models.ForeignKey("Typ_Odpowiedzialnosci", DO_NOTHING)
    zapisany_jako = models.TextField()
    dyscyplina_naukowa = models.ForeignKey("Dyscyplina_Naukowa", DO_NOTHING)

    afiliuje = models.BooleanField()
    zatrudniony = models.BooleanField()
    upowaznienie_pbn = models.BooleanField()
    profil_orcid = models.BooleanField()

    objects = AutorzyManager()

    class Meta:
        abstract = True


class Autorzy(AutorzyBase):
    rekord = models.ForeignKey(
        "bpp.Rekord",
        related_name="autorzy",
        # tak na prawdę w bazie danych jest constraint dla ON_DELETE, ale
        # dajemy to tutaj, żeby django się nie awanturowało i nie próbowało
        # tego ręcznie kasować
        on_delete=DO_NOTHING,
    )

    # To poniżej musi być, bo się django-admin.py sqlflush nie uda
    typ_odpowiedzialnosci = models.ForeignKey("Typ_Odpowiedzialnosci", DO_NOTHING)
    autor = models.ForeignKey("Autor", DO_NOTHING)
    dyscyplina_naukowa = models.ForeignKey("Dyscyplina_Naukowa", DO_NOTHING)

    class Meta:
        managed = False
        db_table = "bpp_autorzy_mat"


class AutorzyView(AutorzyBase):
    rekord = models.ForeignKey(
        "bpp.RekordView",
        related_name="autorzy",
        # tak na prawdę w bazie danych jest constraint dla ON_DELETE, ale
        # dajemy to tutaj, żeby django się nie awanturowało i nie próbowało
        # tego ręcznie kasować
        on_delete=DO_NOTHING,
    )

    class Meta:
        managed = False
        db_table = "bpp_autorzy"


class SlowaKluczoweView(models.Model):
    id = ArrayField(base_field=models.IntegerField(), size=3, primary_key=True)

    rekord = models.ForeignKey(
        "bpp.Rekord", related_name="slowa_kluczowe_set", on_delete=DO_NOTHING
    )
    tag = models.ForeignKey(Tag, on_delete=DO_NOTHING)

    @classmethod
    def tag_relname(cls):
        field = cls._meta.get_field("tag")
        return field.remote_field.related_name

    @classmethod
    def tags_for(cls, model, instance=None, **kwargs):
        if model != Rekord:
            raise NotImplementedError
        if instance is not None:
            return cls.objects.filter(rekord_id=(instance.pk,))
        return cls.objects.all()

    class Meta:
        managed = False
        db_table = "bpp_slowa_kluczowe_view"


class ZewnetrzneBazyDanychView(models.Model):
    rekord = models.ForeignKey(
        "bpp.Rekord", related_name="zewnetrzne_bazy", on_delete=DO_NOTHING
    )

    baza = models.ForeignKey("bpp.Zewnetrzna_Baza_Danych", on_delete=DO_NOTHING)

    info = models.TextField()

    class Meta:
        managed = False
        db_table = "bpp_zewnetrzne_bazy_view"


class RekordManager(FulltextSearchMixin, models.Manager):
    fts_field = "search_index"

    def get_for_model(self, model):
        pk = (ContentType.objects.get_for_model(model).pk, model.pk)
        return self.get(pk=pk)

    def prace_autora(self, autor):
        return self.filter(autorzy__autor=autor).distinct()

    def prace_autora_z_afiliowanych_jednostek(self, autor):
        """
        Funkcja zwraca prace danego autora, należące tylko i wyłącznie
        do jednostek skupiających pracowników, gdzie autor jest zaznaczony jako
        afiliowany.
        """
        return (
            self.prace_autora(autor)
            .filter(
                autorzy__autor=autor,
                autorzy__jednostka__skupia_pracownikow=True,
                autorzy__afiliuje=True,
            )
            .distinct()
        )

    def prace_autor_i_typ(self, autor, skrot):
        return (
            self.prace_autora(autor)
            .filter(
                autorzy__typ_odpowiedzialnosci_id=Typ_Odpowiedzialnosci.objects.get(
                    skrot=skrot
                ).pk
            )
            .distinct()
        )

    def prace_jednostki(self, jednostka, afiliowane=None):
        if afiliowane is None:
            return self.filter(
                autorzy__jednostka__pk__in=list(
                    jednostka.get_descendants(include_self=True).values_list(
                        "pk", flat=True
                    )
                )
            ).distinct()

        return self.filter(
            autorzy__jednostka__pk__in=list(
                jednostka.get_descendants(include_self=True).values_list(
                    "pk", flat=True
                )
            ),
            autorzy__afiliuje=afiliowane,
        ).distinct()

    def prace_wydzialu(self, wydzial, afiliowane=None):
        if afiliowane is None:
            return self.filter(autorzy__jednostka__wydzial=wydzial).distinct()

        return self.filter(
            autorzy__jednostka__wydzial=wydzial, autorzy__afiliuje=afiliowane
        ).distinct()

    def redaktorzy_z_jednostki(self, jednostka):
        return self.filter(
            autorzy__jednostka=jednostka,
            autorzy__typ_odpowiedzialnosci_id=Typ_Odpowiedzialnosci.objects.get(
                skrot="red."
            ).pk,
        ).distinct()

    def get_original(self, model):
        return self.get(pk=[ContentType.objects.get_for_model(model).pk, model.pk])

    def full_refresh(self):
        """Procedura odswieza opisy bibliograficzne dla wszystkich rekordów."""
        denorm.rebuildall("bpp.Wydawnictwo_Zwarte")
        denorm.rebuildall("bpp.Wydawnictwo_Ciagle")
        denorm.rebuildall("bpp.Patent")
        denorm.rebuildall("bpp.Praca_Doktorska")
        denorm.rebuildall("bpp.Praca_Habilitacyjna")


class _MyTaggableManager(_TaggableManager):
    def get_prefetch_queryset(self, instances, queryset=None):
        if queryset is not None:
            raise ValueError("Custom queryset can't be used for this lookup.")

        instance = instances[0]
        db = self._db or router.db_for_read(type(instance), instance=instance)

        fieldname = "rekord_id"
        fk = self.through._meta.get_field(fieldname)
        query = {
            "%s__%s__in"
            % (self.through.tag_relname(), fk.name): {
                obj._get_pk_val() for obj in instances
            }
        }
        join_table = self.through._meta.db_table
        source_col = fk.column
        connection = connections[db]
        qn = connection.ops.quote_name
        qs = (
            self.get_queryset(query)
            .using(db)
            .extra(
                select={
                    "_prefetch_related_val": "{}.{}".format(
                        qn(join_table), qn(source_col)
                    )
                }
            )
        )
        from operator import attrgetter

        rel_obj_attr = attrgetter("_prefetch_related_val")

        return (
            qs,
            rel_obj_attr,
            lambda obj: obj._get_pk_val(),
            False,
            self.prefetch_cache_name,
            False,
        )


class RekordBase(
    ModelPunktowanyBaza,
    ModelZOpisemBibliograficznym,
    ModelZRokiem,
    ModelZWWW,
    ModelZDOI,
    ModelZPBN_UID,
    ModelZeSzczegolami,
    ModelRecenzowany,
    ModelZeZnakamiWydawniczymi,
    ModelZOpenAccess,
    ModelTypowany,
    ModelZCharakterem,
    ModelZKonferencja,
    ModelZISBN,
    ModelZeStatusem,
    models.Model,
):
    id = TupleField(models.IntegerField(), size=2, primary_key=True)

    tekst_przed_pierwszym_autorem = None
    tekst_po_ostatnim_autorze = None

    tytul_oryginalny = models.TextField()
    tytul = models.TextField()
    search_index = VectorField()

    zrodlo = models.ForeignKey(Zrodlo, null=True, on_delete=DO_NOTHING)
    wydawnictwo_nadrzedne = models.ForeignKey(
        Wydawnictwo_Zwarte, null=True, on_delete=DO_NOTHING
    )
    slowa_kluczowe = TaggableManager(
        "Słowa kluczowe",
        through=SlowaKluczoweView,
        blank=True,
        manager=_MyTaggableManager,
    )

    wydawnictwo = models.TextField()

    adnotacje = models.TextField()
    ostatnio_zmieniony = models.DateTimeField()

    tytul_oryginalny_sort = models.TextField()

    liczba_autorow = models.SmallIntegerField()

    liczba_cytowan = models.SmallIntegerField()

    objects = RekordManager()

    opis_bibliograficzny_cache = models.TextField()
    opis_bibliograficzny_autorzy_cache = ArrayField(models.TextField())
    opis_bibliograficzny_zapisani_autorzy_cache = models.TextField()
    slug = models.TextField()

    strony = None
    nr_zeszytu = None
    tom = None

    jezyk_alt = None
    jezyk_orig = None

    # Skróty dla django-dsl

    django_dsl_shortcuts = {
        "charakter": "charakter_formalny__skrot",
        "typ_kbn": "typ_kbn__skrot",
        "typ_odpowiedzialnosci": "autorzy__typ_odpowiedzialnosci__skrot",
        "autor": "autorzy__autor_id",
        "jednostka": "autorzy__jednostka__pk",
        "wydzial": "autorzy__jednostka__wydzial__pk",
    }

    class Meta:
        abstract = True

    def __str__(self):
        return self.tytul_oryginalny

    @cached_property
    def content_type(self):
        return ContentType.objects.get(pk=self.id[0])

    @cached_property
    def describe_content_type(self):
        return ContentType.objects.get(pk=self.id[0]).model_class()._meta.verbose_name

    @cached_property
    def object_id(self):
        return self.id[1]

    @cached_property
    def original(self):
        return self.content_type.get_object_for_this_type(pk=self.object_id)

    @cached_property
    def js_safe_pk(self):
        return "%i_%i" % (self.pk[0], self.pk[1])

    @cached_property
    def ma_punktacje_sloty(self):
        return (
            Cache_Punktacja_Autora.objects.filter(
                rekord_id=[self.id[0], self.id[1]]
            ).exists()
            or Cache_Punktacja_Dyscypliny.objects.filter(
                rekord_id=[self.id[0], self.id[1]]
            ).exists()
        )

    @cached_property
    def ma_odpiete_dyscypliny(self):
        return (
            self.original.autorzy_set.exclude(dyscyplina_naukowa=None)
            .exclude(przypieta=True)
            .exists()
        )

    @cached_property
    def punktacja_dyscypliny(self):
        return Cache_Punktacja_Dyscypliny.objects.filter(
            rekord_id=[self.id[0], self.id[1]]
        )

    @cached_property
    def punktacja_autora(self):
        return Cache_Punktacja_Autora.objects.filter(rekord_id=[self.id[0], self.id[1]])

    @cached_property
    def pierwszy_autor_afiliowany(self):
        """Zwraca pierwszego autora, afiliującego na jednostkę uczelni z tej pracy"""
        return self.autorzy.filter(afiliuje=True).order_by("kolejnosc").first()

    @cached_property
    def pierwsza_jednostka_afiliowana(self):
        """Zwraca pierwszego autora, afiliującego na jednostkę uczelni z tej pracy"""
        res = self.pierwszy_autor_afiliowany()
        if res is not None:
            return self.pierwszy_autor_afiliowany().jednostka


class Rekord(RekordBase):
    class Meta:
        managed = False
        ordering = ["tytul_oryginalny_sort"]
        db_table = "bpp_rekord_mat"

    @cached_property
    def autorzy_set(self):
        return self.autorzy


class RekordView(RekordBase):
    class Meta:
        managed = False
        db_table = "bpp_rekord"


class Cache_Punktacja_Dyscypliny(models.Model):
    rekord_id = TupleField(models.IntegerField(), size=2, db_index=True)
    # rekord = ForeignKey('bpp.Rekord', CASCADE)
    dyscyplina = ForeignKey(Dyscyplina_Naukowa, CASCADE)
    pkd = models.DecimalField(max_digits=20, decimal_places=4)
    slot = models.DecimalField(max_digits=20, decimal_places=4)

    autorzy_z_dyscypliny = ArrayField(
        models.PositiveIntegerField(), blank=True, null=True
    )
    zapisani_autorzy_z_dyscypliny = ArrayField(
        models.TextField(), blank=True, null=True
    )

    class Meta:
        ordering = ("dyscyplina__nazwa",)

    def serialize(self):
        return [self.rekord_id, self.dyscyplina_id, str(self.pkd), str(self.slot)]


class Cache_Punktacja_Autora_Base(models.Model):
    autor = ForeignKey(Autor, CASCADE)
    jednostka = ForeignKey(Jednostka, CASCADE)
    dyscyplina = ForeignKey(Dyscyplina_Naukowa, CASCADE)
    pkdaut = models.DecimalField(max_digits=20, decimal_places=4)
    slot = models.DecimalField(max_digits=20, decimal_places=4)

    class Meta:
        ordering = ("autor__nazwisko", "dyscyplina__nazwa")
        abstract = True


class Cache_Punktacja_Autora(Cache_Punktacja_Autora_Base):
    rekord_id = TupleField(models.IntegerField(), size=2, db_index=True)

    class Meta:
        ordering = ("autor__nazwisko", "dyscyplina__nazwa")

    def serialize(self):
        return [
            self.rekord_id,
            self.autor_id,
            self.jednostka_id,
            self.dyscyplina_id,
            str(self.pkdaut),
            str(self.slot),
        ]


class Cache_Punktacja_Autora_Query(Cache_Punktacja_Autora_Base):
    rekord = ForeignKey("bpp.Rekord", DO_NOTHING)

    class Meta:
        db_table = "bpp_cache_punktacja_autora"
        managed = False


class Cache_Punktacja_Autora_Query_View(models.Model):
    """W porównaniu do Cache_Punktacja_Autora, mam jeszcze listę zapisanych
    autorów z dyscypliny. A skąd? A z widoku bazodanowego, który bierze
    też pod uwagę Cache_Punktacja_Dyscypliny.
    """

    rekord = ForeignKey("bpp.Rekord", DO_NOTHING)
    autor = ForeignKey(Autor, DO_NOTHING)
    jednostka = ForeignKey(Jednostka, DO_NOTHING)
    dyscyplina = ForeignKey(Dyscyplina_Naukowa, DO_NOTHING)
    pkdaut = models.DecimalField(max_digits=20, decimal_places=4)
    slot = models.DecimalField(max_digits=20, decimal_places=4)
    zapisani_autorzy_z_dyscypliny = ArrayField(models.TextField())

    class Meta:
        ordering = ("rekord__tytul_oryginalny", "dyscyplina__nazwa")
        db_table = "bpp_cache_punktacja_autora_view"
        managed = False


class Cache_Punktacja_Autora_Sum(Cache_Punktacja_Autora_Base):
    rekord = ForeignKey("bpp.Rekord", DO_NOTHING)
    autor = ForeignKey(Autor, DO_NOTHING)
    jednostka = ForeignKey(Jednostka, DO_NOTHING)
    dyscyplina = ForeignKey(Dyscyplina_Naukowa, DO_NOTHING)
    pkdautslot = models.FloatField()
    pkdautsum = models.FloatField()
    pkdautslotsum = models.FloatField()

    class Meta:
        db_table = "bpp_temporary_cpaq"
        managed = False
        ordering = (
            "autor",
            "dyscyplina",
            "-pkdautslot",
        )


class Cache_Punktacja_Autora_Sum_Ponizej(Cache_Punktacja_Autora_Base):
    rekord = ForeignKey("bpp.Rekord", DO_NOTHING)
    autor = ForeignKey(Autor, DO_NOTHING)
    jednostka = ForeignKey(Jednostka, DO_NOTHING)
    dyscyplina = ForeignKey(Dyscyplina_Naukowa, DO_NOTHING)
    pkdautslot = models.FloatField()
    pkdautsum = models.FloatField()
    pkdautslotsum = models.FloatField()

    class Meta:
        db_table = "bpp_temporary_cpaq_2"
        managed = False
        ordering = (
            "autor",
            "dyscyplina",
            "pkdautslot",
        )


class Cache_Punktacja_Autora_Sum_Group_Ponizej(models.Model):
    autor = models.OneToOneField(Autor, DO_NOTHING, primary_key=True)
    jednostka = ForeignKey(Jednostka, DO_NOTHING)
    dyscyplina = ForeignKey(Dyscyplina_Naukowa, DO_NOTHING)
    pkdautsum = models.FloatField()
    pkdautslotsum = models.FloatField()

    class Meta:
        db_table = "bpp_temporary_cpasg_2"
        managed = False
        ordering = (
            "autor",
            "dyscyplina",
        )


class Cache_Punktacja_Autora_Sum_Gruop(models.Model):
    autor = models.OneToOneField(Autor, DO_NOTHING, primary_key=True)
    jednostka = ForeignKey(Jednostka, DO_NOTHING)
    dyscyplina = ForeignKey(Dyscyplina_Naukowa, DO_NOTHING)
    pkdautsum = models.FloatField()
    pkdautslotsum = models.FloatField()

    class Meta:
        db_table = "bpp_temporary_cpasg"
        managed = False
        ordering = (
            "autor",
            "dyscyplina",
        )



# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-06-07 10:31
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0133_liczba_autorow'),
    ]

    operations = [
        migrations.AddField(
            model_name='uczelnia',
            name='domyslnie_afiliuje',
            field=models.BooleanField(default=True, help_text='Przy powiązaniach autor + wydawnictwo, zaznaczaj domyślnie,\n        że autor afiliuje do jednostki, która jest wpisywana.', verbose_name='Domyślnie zaznaczaj, że autor afiliuje'),
        ),
    ]



# -*- encoding: utf-8 -*-

from django.core.management import BaseCommand
from django.db import transaction

from bpp.management.commands.import_bpp import set_seq
from bpp.models import (
    Autor,
    Jednostka,
    Wydzial,
    Uczelnia,
    Zrodlo,
    Wydawnictwo_Zwarte,
    Wydawnictwo_Zwarte_Baza,
    cache,
)

from bpp import models


class Command(BaseCommand):
    help = "Zmienia podany charakter wydawnictwa zwartego w doktorat"

    def add_arguments(self, parser):
        parser.add_argument("typ_kbn_nazwa")
        parser.add_argument("klasa_docelowa")

    @transaction.atomic
    def handle(self, typ_kbn_nazwa, klasa_docelowa, *args, **options):
        if cache.enabled():
            cache.disable()

        klasa_docelowa = getattr(models, klasa_docelowa)
        flds = Wydawnictwo_Zwarte_Baza._meta.get_fields()
        flds = [fld.name for fld in flds]
        for elem in Wydawnictwo_Zwarte.objects.filter(typ_kbn__nazwa=typ_kbn_nazwa):

            target_kw = {}
            for fld in flds:
                target_kw[fld] = getattr(elem, fld)

            assert elem.autorzy_set.all().count() == 1

            target_kw["autor"] = elem.autorzy_set.first().autor
            target_kw["jednostka"] = elem.autorzy_set.first().jednostka

            if klasa_docelowa.objects.filter(autor=target_kw["autor"]):
                print(
                    f"*** nie tworze {target_kw['tytul_oryginalny']} bo juz istnieje!'"
                )
                continue

            klasa_docelowa.objects.create(**target_kw)
            elem.delete()
            print(target_kw["tytul_oryginalny"])

        set_seq(klasa_docelowa._meta.db_table)



"""
Autorzy
"""
from __future__ import annotations

from datetime import date, datetime, timedelta

from autoslug import AutoSlugField
from django.core.exceptions import ValidationError
from django.core.validators import RegexValidator
from django.db import IntegrityError, models, transaction
from django.db.models import CASCADE, SET_NULL, Q, Sum, UniqueConstraint
from django.urls.base import reverse

from django.contrib.postgres.search import SearchVectorField as VectorField

from bpp import const
from bpp.core import zbieraj_sloty
from bpp.models import LinkDoPBNMixin, ModelZAdnotacjami, ModelZNazwa, NazwaISkrot
from bpp.models.abstract import ModelZPBN_ID
from bpp.util import FulltextSearchMixin


class Tytul(NazwaISkrot):
    class Meta:
        verbose_name = "tytuł"
        verbose_name_plural = "tytuły"
        app_label = "bpp"
        ordering = ("skrot",)


class Plec(NazwaISkrot):
    class Meta:
        verbose_name = "płeć"
        verbose_name_plural = "płcie"
        app_label = "bpp"


def autor_split_string(text):
    text = text.strip().replace("\t", " ").replace("\n", " ").replace("\r", " ")
    while text.find("  ") >= 0:
        text = text.replace("  ", " ")

    text = [x.strip() for x in text.split(" ", 1)]
    if len(text) != 2:
        raise ValueError(text)

    if not text[0] or not text[1]:
        raise ValueError(text)

    return text[0], text[1]


class AutorManager(FulltextSearchMixin, models.Manager):
    def create_from_string(self, text):
        """Tworzy rekord autora z ciągu znaków. Używane, gdy dysponujemy
        wpisanym ciągiem znaków z np AutorAutocomplete i chcemy utworzyć
        autora z nazwiskiem i imieniem w poprawny sposób."""

        text = autor_split_string(text)

        return self.create(
            **dict(nazwisko=text[0].title(), imiona=text[1].title(), pokazuj=False)
        )


class Autor(LinkDoPBNMixin, ModelZAdnotacjami, ModelZPBN_ID):
    url_do_pbn = const.LINK_PBN_DO_AUTORA

    imiona = models.CharField(max_length=512, db_index=True)
    nazwisko = models.CharField(max_length=256, db_index=True)
    tytul = models.ForeignKey(Tytul, CASCADE, blank=True, null=True)
    pseudonim = models.CharField(
        max_length=300,
        blank=True,
        null=True,
        help_text="""
    Jeżeli w bazie danych znajdują się autorzy o zbliżonych imionach, nazwiskach i tytułach naukowych,
    skorzystaj z tego pola aby ułatwić ich rozróżnienie. Pseudonim pokaże się w polach wyszukiwania
    oraz na podstronie autora, po nazwisku i tytule naukowym.""",
    )

    aktualna_jednostka = models.ForeignKey(
        "Jednostka", CASCADE, blank=True, null=True, related_name="aktualna_jednostka"
    )
    aktualna_funkcja = models.ForeignKey(
        "Funkcja_Autora",
        CASCADE,
        blank=True,
        null=True,
        related_name="aktualna_funkcja",
    )

    pokazuj = models.BooleanField(
        default=True, help_text="Pokazuj autora na stronach jednostek oraz w rankingu. "
    )

    email = models.EmailField("E-mail", max_length=128, blank=True, null=True)
    www = models.URLField("WWW", max_length=1024, blank=True, null=True)

    plec = models.ForeignKey(Plec, CASCADE, null=True, blank=True)

    urodzony = models.DateField(blank=True, null=True)
    zmarl = models.DateField(blank=True, null=True)
    poprzednie_nazwiska = models.CharField(
        max_length=1024,
        blank=True,
        null=True,
        help_text="""Jeżeli ten
        autor(-ka) posiada nazwisko panieńskie, pod którym ukazywały
        się publikacje lub zmieniał nazwisko z innych powodów, wpisz tutaj
        wszystkie poprzednie nazwiska, oddzielając je przecinkami.""",
        db_index=True,
    )
    pokazuj_poprzednie_nazwiska = models.BooleanField(
        default=True,
        help_text="Jeżeli odznaczone, poprzednie nazwiska nie będą się wyświetlać na podstronie autora "
        "dla użytkowników niezalogowanych. Użytkownicy zalogowani widzą je zawsze. Wyszukiwanie po poprzednich "
        "nazwiskach będzie nadal możliwe. ",
    )
    orcid = models.CharField(
        "Identyfikator ORCID",
        max_length=19,
        blank=True,
        null=True,
        unique=True,
        help_text="Open Researcher and Contributor ID, " "vide http://www.orcid.org",
        validators=[
            RegexValidator(
                regex=r"^\d\d\d\d-\d\d\d\d-\d\d\d\d-\d\d\d(\d|X)$",
                message="Identyfikator ORCID to 4 grupy po 4 cyfry w każdej, "
                "oddzielone myślnikami",
                code="orcid_invalid_format",
            ),
        ],
        db_index=True,
    )
    orcid_w_pbn = models.BooleanField(
        "ORCID jest w bazie PBN?",
        help_text="""Jeżeli ORCID jest w bazie PBN, to pole powinno być zaznaczone. Zaznaczenie następuje
        automatycznie, przez procedury integrujące bazę danych z PBNem w nocy. Można też zaznaczyć ręcznie.
        Pole wykorzystywane jest gdy autor nie ma odpowiednika w PBN (pole 'PBN UID' rekordu autora jest puste,
        zaś eksport danych powoduje komunikat zwrotny z PBN o nieistniejącym w ich bazie ORCID). W takich sytuacjach
        należy w polu wybrać "Nie". """,
        null=True,
    )

    expertus_id = models.CharField(
        "Identyfikator w bazie Expertus",
        max_length=10,
        null=True,
        blank=True,
        db_index=True,
        unique=True,
    )

    system_kadrowy_id = models.PositiveIntegerField(
        "Identyfikator w systemie kadrowym",
        help_text="""Identyfikator cyfrowy, używany do matchowania autora z danymi z systemu kadrowego Uczelni""",
        null=True,
        blank=True,
        db_index=True,
        unique=True,
    )

    pbn_uid = models.ForeignKey(
        "pbn_api.Scientist", null=True, blank=True, on_delete=SET_NULL
    )

    search = VectorField()

    objects = AutorManager()

    slug = AutoSlugField(populate_from="get_full_name", unique=True, max_length=1024)

    sort = models.TextField()

    jednostki = models.ManyToManyField("bpp.Jednostka", through="Autor_Jednostka")

    def get_absolute_url(self):
        return reverse("bpp:browse_autor", args=(self.slug,))

    class Meta:
        verbose_name = "autor"
        verbose_name_plural = "autorzy"
        ordering = ["sort"]
        app_label = "bpp"

    def __str__(self):
        buf = f"{self.nazwisko} {self.imiona}"

        if self.poprzednie_nazwiska and self.pokazuj_poprzednie_nazwiska:
            buf += " (%s)" % self.poprzednie_nazwiska

        if self.tytul is not None:
            buf += ", " + self.tytul.skrot

        if self.pseudonim is not None:
            buf += " (" + self.pseudonim + ")"

        return buf

    def dodaj_jednostke(
        self, jednostka, rok=None, funkcja=None
    ) -> Autor_Jednostka | None:

        start_pracy = None
        koniec_pracy = None

        if rok is not None:
            start_pracy = date(rok, 1, 1)
            koniec_pracy = date(rok, 12, 31)

        czy_juz_istnieje = Autor_Jednostka.objects.filter(
            autor=self,
            jednostka=jednostka,
            rozpoczal_prace__lte=start_pracy or date(1, 1, 1),
            zakonczyl_prace__gte=koniec_pracy or date(999, 12, 31),
        )

        if czy_juz_istnieje.exists():
            # Ten czas jest już pokryty
            return czy_juz_istnieje.first()

        try:
            ret = Autor_Jednostka.objects.create(
                autor=self,
                jednostka=jednostka,
                funkcja=funkcja,
                rozpoczal_prace=start_pracy,
                zakonczyl_prace=koniec_pracy,
            )
        except IntegrityError:
            return
        self.defragmentuj_jednostke(jednostka)

        return ret

    def defragmentuj_jednostke(self, jednostka):
        Autor_Jednostka.objects.defragmentuj(autor=self, jednostka=jednostka)

    def save(self, *args, **kw):
        self.sort = (self.nazwisko.lower().replace("von ", "") + self.imiona).lower()
        ret = super().save(*args, **kw)

        for jednostka in self.jednostki.all():
            self.defragmentuj_jednostke(jednostka)

        return ret

    def afiliacja_na_rok(self, rok, wydzial, rozszerzona=False):
        """
        Czy autor w danym roku był w danym wydziale?

        :param rok:
        :param wydzial:
        :return: True gdy w danym roku był w danym wydziale
        """
        start_pracy = date(rok, 1, 1)
        koniec_pracy = date(rok, 12, 31)

        if Autor_Jednostka.objects.filter(
            autor=self,
            rozpoczal_prace__lte=start_pracy,
            zakonczyl_prace__gte=koniec_pracy,
            jednostka__wydzial=wydzial,
        ):
            return True

        # A może ma wpisaną tylko datę początku pracy? W takiej sytuacji
        # stwierdzamy, że autor NADAL tam pracuje, bo nie ma końca, więc:
        if Autor_Jednostka.objects.filter(
            autor=self,
            rozpoczal_prace__lte=start_pracy,
            zakonczyl_prace=None,
            jednostka__wydzial=wydzial,
        ):
            return True

        # Jeżeli nie ma takiego rekordu z dopasowaniem z datami, to może jest
        # rekord z dopasowaniem JAKIMKOLWIEK innym?
        # XXX po telefonie p. Małgorzaty Zając dnia 2013-03-25 o godzinie 11:55
        # dostałem informację, że NIE interesują nas tacy autorzy, zatem:

        if not rozszerzona:
            return

        # ... aczkolwiek, sprawdzanie afiliacji do wydziału dla niektórych autorów może
        # być przydatne np przy importowaniu imion i innych rzeczy, więc sprawdźmy w sytuacj
        # gdy jest rozszerzona afiliacja:

        if Autor_Jednostka.objects.filter(autor=self, jednostka__wydzial=wydzial):
            return True

    def get_full_name(self):
        buf = f"{self.imiona} {self.nazwisko}"
        if self.poprzednie_nazwiska:
            buf += " (%s)" % self.poprzednie_nazwiska
        return buf

    def get_full_name_surname_first(self):
        buf = "%s" % self.nazwisko
        if self.poprzednie_nazwiska:
            buf += " (%s)" % self.poprzednie_nazwiska
        buf += " %s" % self.imiona
        return buf

    def prace_w_latach(self):
        """Zwraca lata, w których ten autor opracowywał jakiekolwiek prace."""
        from bpp.models.cache import Rekord

        return (
            Rekord.objects.prace_autora(self)
            .values_list("rok", flat=True)
            .distinct()
            .order_by("rok")
        )

    def liczba_cytowan(self):
        """Zwraca liczbę cytowań prac danego autora"""
        from bpp.models.cache import Rekord

        return (
            Rekord.objects.prace_autora(self)
            .distinct()
            .aggregate(s=Sum("liczba_cytowan"))["s"]
        )

    def liczba_cytowan_afiliowane(self):
        """Zwraca liczbę cytowań prac danego autora tam,
        gdzie została podana afiliacja na jednostkę uczelni"""
        from bpp.models.cache import Rekord

        return (
            Rekord.objects.prace_autora_z_afiliowanych_jednostek(self)
            .distinct()
            .aggregate(s=Sum("liczba_cytowan"))["s"]
        )

    def jednostki_gdzie_ma_publikacje(self):
        from bpp.models import Autorzy, Jednostka

        return Jednostka.objects.filter(
            pk__in=Autorzy.objects.filter(autor_id=self.pk)
            .values("jednostka_id")
            .distinct()
        )

    def zbieraj_sloty(
        self,
        zadany_slot,
        rok_min,
        rok_max,
        minimalny_pk=None,
        dyscyplina_id=None,
        jednostka_id=None,
        akcja=None,
    ):
        return zbieraj_sloty(
            autor_id=self.pk,
            zadany_slot=zadany_slot,
            rok_min=rok_min,
            rok_max=rok_max,
            minimalny_pk=minimalny_pk,
            dyscyplina_id=dyscyplina_id,
            jednostka_id=jednostka_id,
            akcja=akcja,
        )


class Funkcja_Autora(NazwaISkrot):
    """Funkcja autora w jednostce"""

    pokazuj_za_nazwiskiem = models.BooleanField(
        default=False,
        help_text="""Zaznaczenie tego pola sprawi, że ta funkcja
        będzie wyświetlana na stronie autora, za nazwiskiem.""",
    )

    class Meta:
        verbose_name = "funkcja w jednostce"
        verbose_name_plural = "funkcje w jednostkach"
        ordering = ["nazwa"]
        app_label = "bpp"


class Grupa_Pracownicza(ModelZNazwa):
    class Meta:
        verbose_name = "grupa pracownicza"
        verbose_name_plural = "grupy pracownicze"
        ordering = [
            "nazwa",
        ]
        app_label = "bpp"


class Wymiar_Etatu(ModelZNazwa):
    class Meta:
        verbose_name = "wymiar etatu"
        verbose_name_plural = "wymiary etatów"
        ordering = ["nazwa"]
        app_label = "bpp"


class Autor_Jednostka_Manager(models.Manager):
    def defragmentuj(self, autor, jednostka):
        poprzedni_rekord = None
        usun = []
        for rec in Autor_Jednostka.objects.filter(
            autor=autor, jednostka=jednostka
        ).order_by("rozpoczal_prace"):

            if poprzedni_rekord is None:
                poprzedni_rekord = rec
                continue

            if rec.rozpoczal_prace is None and rec.zakonczyl_prace is None:
                # Nic nie wnosi tutaj taki rekord ORAZ nie jest to 'poprzedni'
                # rekord, więc:
                usun.append(rec)
                continue

            # Przy imporcie danych z XLS na dane ze starego systemu - obydwa pola są None
            if (
                poprzedni_rekord.zakonczyl_prace is None
                and poprzedni_rekord.rozpoczal_prace is None
            ):
                usun.append(poprzedni_rekord)
                poprzedni_rekord = rec
                continue

            # Nowy system - przy imporcie danych z XLS do nowego systemu jest sytuacja, gdy autor
            # zaczął kiedyśtam prace ALE jej nie zakończył:
            if poprzedni_rekord.zakonczyl_prace is None:
                if (
                    rec.rozpoczal_prace is None
                    and poprzedni_rekord.rozpoczal_prace is not None
                ):
                    if rec.zakonczyl_prace == poprzedni_rekord.rozpoczal_prace:
                        usun.append(rec)
                        poprzedni_rekord.rozpoczal_prace = rec.rozpoczal_prace
                        poprzedni_rekord.save()

                    continue

                if rec.rozpoczal_prace >= poprzedni_rekord.rozpoczal_prace:
                    usun.append(rec)
                    poprzedni_rekord.zakonczyl_prace = rec.zakonczyl_prace
                    poprzedni_rekord.save()
                    continue

            if rec.rozpoczal_prace == poprzedni_rekord.zakonczyl_prace + timedelta(
                days=1
            ):
                usun.append(rec)
                poprzedni_rekord.zakonczyl_prace = rec.zakonczyl_prace
                poprzedni_rekord.save()
            else:
                poprzedni_rekord = rec

        for aj in usun:
            aj.delete()


class Autor_Jednostka(models.Model):
    """Powiązanie autora z jednostką"""

    autor = models.ForeignKey(Autor, CASCADE)
    jednostka = models.ForeignKey("bpp.Jednostka", CASCADE)
    rozpoczal_prace = models.DateField(
        "Rozpoczął pracę", blank=True, null=True, db_index=True
    )
    zakonczyl_prace = models.DateField(
        "Zakończył pracę", null=True, blank=True, db_index=True
    )
    funkcja = models.ForeignKey(Funkcja_Autora, CASCADE, null=True, blank=True)

    podstawowe_miejsce_pracy = models.BooleanField(null=True, blank=True, default=None)

    grupa_pracownicza = models.ForeignKey(
        Grupa_Pracownicza, SET_NULL, null=True, blank=True
    )
    wymiar_etatu = models.ForeignKey(Wymiar_Etatu, SET_NULL, null=True, blank=True)

    objects = Autor_Jednostka_Manager()

    def clean(self, exclude=None):
        if self.rozpoczal_prace is not None and self.zakonczyl_prace is not None:
            if self.rozpoczal_prace >= self.zakonczyl_prace:
                raise ValidationError(
                    "Początek pracy późniejszy lub równy, jak zakończenie"
                )

        if self.zakonczyl_prace is not None:
            if self.zakonczyl_prace >= datetime.now().date():
                raise ValidationError(
                    "Czas zakończenia pracy w jednostce nie może być taki sam"
                    " lub większy, jak obecna data"
                )

        if self.podstawowe_miejsce_pracy:
            czy_istnieje = Autor_Jednostka.objects.filter(
                autor_id=self.autor_id, podstawowe_miejsce_pracy=True
            )
            if self.pk:
                czy_istnieje = czy_istnieje.exclude(pk=self.pk)

            if czy_istnieje.exists():
                raise ValidationError(
                    "Ten autor ma już określone podstawowe miejsce pracy. Najpierw usuń podstawowe "
                    f"miejsce pracy (ustaw wartość na 'Nie' dla jednostki '{czy_istnieje.first().jednostka.nazwa}'), "
                    f"następnie zapisz rekord autora, następnie ustaw ponownie właściwe podstawowe miejsce pracy "
                    f"(ustaw wartość na 'Tak') i zapisz po raz kolejny. "
                )

    def __str__(self):
        buf = f"{self.autor} ↔ {self.jednostka.skrot}"
        if self.funkcja:
            buf = f"{self.autor} ↔ {self.funkcja.nazwa}, {self.jednostka.skrot}"
        return buf

    @transaction.atomic
    def ustaw_podstawowe_miejsce_pracy(self):
        """Ustawia to miejsce pracy jako podstawowe i wszystkie pozostałe jako nie-podstawowe"""
        Autor_Jednostka.objects.filter(
            autor=self.autor, podstawowe_miejsce_pracy=True
        ).exclude(pk=self.pk).update(podstawowe_miejsce_pracy=False)
        self.podstawowe_miejsce_pracy = True
        self.save()

    class Meta:
        verbose_name = "powiązanie autor-jednostka"
        verbose_name_plural = "powiązania autor-jednostka"
        ordering = ["autor__nazwisko", "rozpoczal_prace", "jednostka__nazwa"]
        unique_together = [("autor", "jednostka", "rozpoczal_prace")]
        app_label = "bpp"
        constraints = [
            UniqueConstraint(
                fields=["autor_id"],
                condition=Q(podstawowe_miejsce_pracy=True),
                name="jedno_podstawowe_miejsce_pracy_na_autora",
            )
        ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.5 on 2017-11-10 23:35
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0112_fix_refresh_cache'),
    ]

    operations = [
        migrations.AlterField(
            model_name='patent_autor',
            name='rekord',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='autorzy_set', to='bpp.Patent'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle_autor',
            name='rekord',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='autorzy_set', to='bpp.Wydawnictwo_Ciagle'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte_autor',
            name='rekord',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='autorzy_set', to='bpp.Wydawnictwo_Zwarte'),
        ),
    ]



# -*- encoding: utf-8 -*-

from django.core.management import BaseCommand
from django.db import transaction
from bpp.models import Autor, Jednostka, Wydzial, Uczelnia, Zrodlo


class Command(BaseCommand):
    help = 'Odbudowuje pola slug'

    @transaction.atomic
    def handle(self, *args, **options):
        for klass in [Autor, Jednostka, Wydzial, Uczelnia, Zrodlo]:
            for model in klass.objects.all():
                model.slug = None
                model.save()


import os

from django.db import models
from django.db.models import CASCADE

from bpp.models.profile import BppUser

STATUSY = [
    (0, "dodany"),
    (1, "w trakcie analizy"),
    (2, "przetworzony"),
    (3, "przetworzony z błędami"),
]


class BaseIntegration(models.Model):
    """
    Import danch z zewnętrznych plików wejściowych w trybie wsadowym odbywa się w 3 etapach:

    1) otwarcie pliku wejściowego i wprowadzenie danych z pliku wejściowego do bazy
        - procedura input_file_to_dict_stream oraz dict_stream_to_db
        - na tym etapie dane są walidowane pod kątem kompletności (czy np wszystkie pola wypełnione),

    2) zmatchowanie rekordów w bazie danych
        - rekordy wprowadzone do bazy danych w punkcie 1 są uzupełniane o informacje z systemu,
        - najczęściej polega to na dopasowaniu ID rekordu w systemie z danymi z rekordu wprowadzonego

    3) zintegrowanie danch do bazy danych
        - procedura integrate_data

    Import powinien też odbywać się w trybie interaktywnym, wówczas użytkownik może np. zobaczyć
    na WWW listę rekordów np. po przejściu punktu 2 - tylko rekordy które "nie weszły", poprawić je ręcznie
    i wywołać ponownie punkt 3. Ta funkcjonalność obecnie jest jedynie planowana, ale kod importera
    powinien umożliwiać tego typu zachowanie.

    """

    name = models.CharField("Nazwa pliku", max_length=255)

    file = models.FileField(verbose_name="Plik", upload_to="integrator2")
    owner = models.ForeignKey(BppUser, CASCADE)

    uploaded_on = models.DateTimeField(auto_now_add=True)
    last_updated_on = models.DateTimeField(auto_now=True)

    status = models.IntegerField(choices=STATUSY, default=STATUSY[0][0])
    extra_info = models.TextField()  # ekstra informacje dla statusu

    klass = None  # zobacz self.records()

    class Meta:
        verbose_name = "Plik integracji danych"
        ordering = ["-last_updated_on"]
        abstract = True

    def model_name(self):
        """Na potrzeby tworzenia linku URL w template."""
        return self._meta.model_name

    def verbose_name(self):
        """Na potrzeby pokazania ładnej nazwy w template."""
        return self._meta.verbose_name

    def filename(self):
        "Zwróć ładną nazwę pliku - na potrzeby GUI"
        return os.path.basename(self.file.name)

    def records(self):
        "Zwraca rekordy podrzędne dla tej integracji. Zaimplementuj w klasach dziedziczących."
        return self.klass.objects.filter(parent=self)

    def integrated(self):
        return self.records().filter(zintegrowano=True)

    def not_integrated(self):
        return self.records().exclude(zintegrowano=True).order_by("extra_info")

    def input_file_to_dict_stream(self):
        """Otwiera plik wejściowy, wyszukuje nagłówek, a następnie zaczyna
        zwracać kolejne rekordy w formie słowników."""
        raise NotImplementedError

    def dict_stream_to_db(self, dict_stream):
        """Przyjmuje jako parametr wejściowy strumień słowników, a następnie
        dodaje je do bazy dancyh."""
        raise NotImplementedError

    def match_single_record(self, elem):
        """Matchuj jeden rekord. Zobacz komentarz do
        :function:`integrator2.models.base.BaseIntegration.match_records`."""
        raise NotImplementedError

    def match_records(self):
        """Dopasowuje zaimportowane rekordy do informacji zawartej w bazie danych. Najczęściej
        polega to na uzupełnieniu ID powiązanego rekordu w systemie, dopasowanego do zaimportowanych
        informacji."""
        for elem in self.records():
            self.match_single_record(elem)
            elem.zanalizowano = True
            elem.save()

    def integrate(self):
        """Integruje wszystkie dane."""
        for elem in self.records().filter(
            zanalizowano=True,
            moze_byc_zintegrowany_automatycznie=True,
            zintegrowano=False,
        ):
            self.integrate_single_record(elem)
            elem.zintegrowano = True
            elem.save()


class BaseIntegrationElement(models.Model):
    """Pojedynczy element zbioru integrowanych danych.

    Po dodaniu do bazy danych, domyślnie model nie jest zanalizowany, nie jest zintegrowany,
    a jego status jest nieokreślony.

    zanalizowany - system przyjrzał się na ten element,

    może byc zintegrowany automatycznie - wszystko OK, można wkładać dane z tego elementu do systemu,

    zintegrowano - dane z tego elementu zostały dodane.
    """

    zanalizowano = models.BooleanField(default=False)
    moze_byc_zintegrowany_automatycznie = models.BooleanField(
        default=None, null=True, blank=True
    )
    extra_info = models.TextField()

    zintegrowano = models.BooleanField(default=False)

    # parent!

    class Meta:
        abstract = True


# INTEGRATOR_DOI = 0
# INTEGRATOR_ATOZ = 1
# INTEGRATOR_AUTOR = 2
# INTEGRATOR_AUTOR_BEZ_PBN = 3
# INTEGRATOR_LISTA_MINISTERIALNA = 4
#
# RODZAJE = [
#     (INTEGRATOR_DOI, "lista DOI"),
#     (INTEGRATOR_ATOZ, "lista AtoZ"),
#     (INTEGRATOR_AUTOR, "integracja autorów"),
#     (INTEGRATOR_AUTOR_BEZ_PBN, "integracja autorów bez PBN ID"),
#     (INTEGRATOR_LISTA_MINISTERIALNA, "import punktów z list ministerialnych")
# ]



from pbn_api.integrator import DELETED


def odswiez_tabele_publikacji_init(_client):
    import django

    django.setup()

    global client, _pobierz_pojedyncza_prace
    client = _client

    from pbn_api.integrator import _pobierz_pojedyncza_prace as f

    _pobierz_pojedyncza_prace = f


def odswiez_tabele_single_task(mongoId):
    _pobierz_pojedyncza_prace(client, mongoId)


def odswiez_tabele_publikacji(client):
    """Odświeża wszystkie publikacje, które są w lokalnej tabeli."""
    from pbn_api.integrator import _bede_uzywal_bazy_danych_z_multiprocessing_z_django
    from pbn_api.models import Publication

    from bpp.util import pbar

    _bede_uzywal_bazy_danych_z_multiprocessing_z_django()

    from multiprocessing import Pool

    pool = Pool(
        processes=8, initializer=odswiez_tabele_publikacji_init, initargs=(client,)
    )

    ids = list(Publication.objects.exclude(status=DELETED).values_list("pk", flat=True))
    for _ in pbar(
        pool.imap_unordered(
            odswiez_tabele_single_task,
            ids,
        ),
        count=len(ids),
        label="odswiez_tabele_publikacji",
    ):
        pass

    pool.close()
    pool.join()



# -*- encoding: utf-8 -*-

from django.conf import settings

def google_analytics(request):
    """
    Use the variables returned in this function to
    render your Google Analytics tracking code template.
    """
    ga_prop_id = getattr(settings, 'GOOGLE_ANALYTICS_PROPERTY_ID', False)
    if (settings.DEBUG != True) and (ga_prop_id != ""):
        return {
            'GOOGLE_ANALYTICS_PROPERTY_ID': ga_prop_id,
        }
    return {}


from django.conf.urls import url
from django.urls import path
from django.views.decorators.csrf import csrf_exempt

from django.contrib.auth.decorators import login_required

import bpp
from bpp import reports  # noqa
from bpp.views.api import (
    OstatniaJednostkaIDyscyplinaView,
    PunktacjaZrodlaView,
    RokHabilitacjiView,
    UploadPunktacjaZrodlaView,
)
from bpp.views.api.clarivate import GetWoSAMRInformation
from bpp.views.api.pbn_get_by_parameter import (
    GetPBNPublicationsByDOI,
    GetPBNPublicationsByISBN,
)
from bpp.views.api.pubmed import GetPubmedIDView
from bpp.views.api.strona_tom_nr_zeszytu import StronaTomNrZeszytuView
from bpp.views.api.uzupelnij_rok import (
    ApiUzupelnijRokWydawnictwoCiagleView,
    ApiUzupelnijRokWydawnictwoZwarteView,
)
from bpp.views.autocomplete import (
    AdminNavigationAutocomplete,
    AutorAutocomplete,
    AutorZUczelniAutocopmlete,
    Dyscyplina_Naukowa_PrzypisanieAutocomplete,
    Dyscyplina_NaukowaAutocomplete,
    GlobalNavigationAutocomplete,
    JednostkaAutocomplete,
    KonferencjaAutocomplete,
    LataAutocomplete,
    OrganPrzyznajacyNagrodyAutocomplete,
    PodrzednaPublikacjaHabilitacyjnaAutocomplete,
    PublicAutorAutocomplete,
    PublicJednostkaAutocomplete,
    PublicKonferencjaAutocomplete,
    PublicTaggitTagAutocomplete,
    PublicWydawnictwo_NadrzedneAutocomplete,
    PublicWydzialAutocomplete,
    PublicZrodloAutocomplete,
    Seria_WydawniczaAutocomplete,
    WidocznaJednostkaAutocomplete,
    WydawcaAutocomplete,
    Wydawnictwo_CiagleAdminAutocomplete,
    Wydawnictwo_NadrzedneAutocomplete,
    Wydawnictwo_ZwarteAdminAutocomplete,
    WydzialAutocomplete,
    ZapisanyJakoAutocomplete,
    Zewnetrzna_Baza_DanychAutocomplete,
    ZrodloAutocomplete,
)
from bpp.views.autocomplete.pbn_api import (
    JournalAutocomplete,
    PublicationAutocomplete,
    ScientistAutocomplete,
)
from bpp.views.browse import (
    AutorView,
    AutorzyView,
    BuildSearch,
    JednostkaView,
    JednostkiView,
    OldPracaView,
    PracaView,
    PracaViewBySlug,
    RekordToPracaView,
    UczelniaView,
    WydzialView,
    ZrodlaView,
    ZrodloView,
)
from bpp.views.oai import OAIView
from bpp.views.raporty import (
    KasowanieRaportu,
    PobranieRaportu,
    PodgladRaportu,
    RankingAutorow,
    RankingAutorowFormularz,
    RaportAutorow,
    RaportDlaKomisjiCentralnejFormularz,
    RaportJednostek,
    RaportJednostek2012,
    RaportSelector,
)
from bpp.views.raporty.raport_autorow_2012 import RaportAutorow2012

urlpatterns = [
    url(
        r"^api/rok-habilitacji/$",
        csrf_exempt(RokHabilitacjiView.as_view()),
        name="api_rok_habilitacji",
    ),
    url(
        r"^api/punktacja-zrodla/(?P<zrodlo_id>[\d]+)/(?P<rok>[\d]+)/$",
        csrf_exempt(PunktacjaZrodlaView.as_view()),
        name="api_punktacja_zrodla",
    ),
    url(
        r"^api/upload-punktacja-zrodla/(?P<zrodlo_id>[\d]+)/(?P<rok>[\d]+)/$",
        csrf_exempt(UploadPunktacjaZrodlaView.as_view()),
        name="api_upload_punktacja_zrodla",
    ),
    url(
        r"^api/ostatnia-jednostka-i-dyscyplina/$",
        csrf_exempt(OstatniaJednostkaIDyscyplinaView.as_view()),
        name="api_ostatnia_jednostka_i_dyscyplina",
    ),
    url(
        r"^api/pubmed-id/$",
        csrf_exempt(GetPubmedIDView.as_view()),
        name="api_pubmed_id",
    ),
    url(
        r"^api/get-pbn-publications-by-isbn/$",
        csrf_exempt(GetPBNPublicationsByISBN.as_view()),
        name="api_get_pbn_by_isbn",
    ),
    url(
        r"^api/get-pbn-publications-by-doi/$",
        csrf_exempt(GetPBNPublicationsByDOI.as_view()),
        name="api_get_pbn_by_doi",
    ),
    url(
        r"^api/(?P<slug>[\w-]+)/wos-amr/$",
        csrf_exempt(GetWoSAMRInformation.as_view()),
        name="api_wos_amr",
    ),
    url(
        r"^api/strona-tom-nr-zeszytu/$",
        csrf_exempt(StronaTomNrZeszytuView.as_view()),
        name="api_strona_tom_nr_zeszytu",
    ),
    url(
        r"^api/uzupelnij_rok_wydawnictwo_zwarte/$",
        csrf_exempt(ApiUzupelnijRokWydawnictwoZwarteView.as_view()),
        name="api_uzupelnij_rok_wydawnictwo_zwarte",
    ),
    url(
        r"^api/uzupelnij_rok_wydawnictwo_ciagle/$",
        csrf_exempt(ApiUzupelnijRokWydawnictwoCiagleView.as_view()),
        name="api_uzupelnij_rok_wydawnictwo_ciagle",
    ),
    url(r"^oai/", OAIView.as_view(), name="oai"),
    url(
        r"^jednostka/(?P<slug>[\w-]+)/$",
        JednostkaView.as_view(),
        name="browse_jednostka",
    ),
    url(r"^jednostki/$", JednostkiView.as_view(), name="browse_jednostki"),
    url(
        r"^jednostki/(?P<literka>.)/$",
        JednostkiView.as_view(),
        name="browse_jednostki_literka",
    ),
    url(r"^wydzial/(?P<slug>[\w-]+)/$", WydzialView.as_view(), name="browse_wydzial"),
    url(
        r"^uczelnia/(?P<slug>[\w-]+)/$", UczelniaView.as_view(), name="browse_uczelnia"
    ),
    url(
        r"^uczelnia/(?P<slug>[\w-]+)/(?P<article_slug>[\w-]+)/$",
        UczelniaView.as_view(),
        name="browse_artykul",
    ),
    url(r"^autorzy/$", AutorzyView.as_view(), name="browse_autorzy"),
    url(
        r"^autorzy/(?P<literka>.)/$",
        AutorzyView.as_view(),
        name="browse_autorzy_literka",
    ),
    url(r"^autor/(?P<pk>\d+)/$", AutorView.as_view(), name="browse_autor"),
    url(r"^autor/(?P<slug>[\w-]+)/$", AutorView.as_view(), name="browse_autor"),
    url(r"^zrodla/$", ZrodlaView.as_view(), name="browse_zrodla"),
    url(
        r"^zrodla/(?P<literka>.)/$", ZrodlaView.as_view(), name="browse_zrodla_literka"
    ),
    url(r"^zrodlo/(?P<slug>[\w-]+)/$", ZrodloView.as_view(), name="browse_zrodlo"),
    url(
        r"^(?P<model>[\w_]+)/(?P<pk>[\d]+)/$",
        OldPracaView.as_view(),
        name="browse_praca_old",
    ),
    url(
        r"^rekord/(?P<model>[\w_]+),(?P<pk>[\d]+)/$",
        PracaView.as_view(),
        name="browse_praca",
    ),
    path(
        "rekord/<slug:slug>/",
        PracaViewBySlug.as_view(),
        name="browse_praca_by_slug",
    ),
    url(
        r"^rekord/(?P<content_type_id>[\d]+),(?P<object_id>[\d]+)/$",
        RekordToPracaView.as_view(),
        name="browse_rekord",
    ),
    url(r"^build_search/$", BuildSearch.as_view(), name="browse_build_search"),
    url(r"^raporty/$", login_required(RaportSelector.as_view()), name="raporty"),
    url(
        r"^raporty/jednostek/$",
        RaportJednostek.as_view(),
        name="raport_jednostek_formularz",
    ),
    url(
        r"^raporty/autorow/$", RaportAutorow.as_view(), name="raport_autorow_formularz"
    ),
    url(
        r"^raporty/ranking-autorow/wybierz/$",
        RankingAutorowFormularz.as_view(),
        name="ranking_autorow_formularz",
    ),
    url(
        r"^raporty/dla-komisji-centralnej/$",
        login_required(RaportDlaKomisjiCentralnejFormularz.as_view()),
        name="raport_dla_komisji_centralnej",
    ),
    url(
        r"^raporty/pobranie/(?P<uid>[\w-]+)/$",
        login_required(PobranieRaportu.as_view()),
        name="pobranie-raportu",
    ),
    url(
        r"^raporty/podglad/(?P<uid>[\w-]+)/skasuj/$",
        login_required(KasowanieRaportu.as_view()),
        name="kasowanie-raportu",
    ),
    url(
        r"^raporty/podglad/(?P<uid>[\w-]+)/$",
        login_required(PodgladRaportu.as_view()),
        name="podglad-raportu",
    ),
    url(
        r"^raporty/ranking-autorow/(?P<od_roku>\d+)/(?P<do_roku>\d+)/$",
        RankingAutorow.as_view(),
        name="ranking-autorow",
    ),
    url(
        r"^raporty/raport-jednostek-2012/(?P<pk>\d+)/(?P<rok_min>\d+)-(?P<rok_max>\d+)/$",
        RaportJednostek2012.as_view(),
        name="raport-jednostek-rok-min-max",
    ),
    url(
        r"^raporty/raport-jednostek-2012/(?P<pk>\d+)/(?P<rok_min>\d+)/$",
        RaportJednostek2012.as_view(),
        name="raport-jednostek",
    ),
    url(
        r"^raporty/raport-autorow-2012/(?P<pk>\d+)/(?P<rok_min>\d+)-(?P<rok_max>\d+)/$",
        RaportAutorow2012.as_view(),
        name="raport-autorow-rok-min-max",
    ),
    url(
        r"^raporty/raport-autorow-2012/(?P<pk>\d+)/(?P<rok_min>\d+)/$",
        RaportAutorow2012.as_view(),
        name="raport-autorow",
    ),
    url(r"^$", bpp.views.root, name="root"),
    url(
        r"^update-multiseek-title/$",
        bpp.views.update_multiseek_title,
        name="update_multiseek_title",
    ),
    url(
        r"^konferencja-autocomplete/$",
        KonferencjaAutocomplete.as_view(),
        name="konferencja-autocomplete",
    ),
    url(
        r"^publication-autocomplete/$",
        PublicationAutocomplete.as_view(),
        name="publication-autocomplete",
    ),
    url(
        r"^scientist-autocomplete/$",
        ScientistAutocomplete.as_view(),
        name="scientist-autocomplete",
    ),
    url(
        r"^journal-autocomplete/$",
        JournalAutocomplete.as_view(),
        name="journal-autocomplete",
    ),
    url(
        r"^public-konferencja-autocomplete/$",
        PublicKonferencjaAutocomplete.as_view(),
        name="public-konferencja-autocomplete",
    ),
    url(
        r"^wydzial-autocomplete/$",
        WydzialAutocomplete.as_view(),
        name="wydzial-autocomplete",
    ),
    url(
        r"^wydawnictwo-ciagle-admin-autocomplete/$",
        Wydawnictwo_CiagleAdminAutocomplete.as_view(),
        name="wydawnictwo-ciagle-admin-autocomplete",
    ),
    url(
        r"^wydawnictwo-zwarte-admin-autocomplete/$",
        Wydawnictwo_ZwarteAdminAutocomplete.as_view(),
        name="wydawnictwo-zwarte-admin-autocomplete",
    ),
    url(
        r"^public-wydzial-autocomplete/$",
        PublicWydzialAutocomplete.as_view(),
        name="public-wydzial-autocomplete",
    ),
    url(
        r"^seria-wydawnicza-autocomplete/$",
        Seria_WydawniczaAutocomplete.as_view(),
        name="seria-wydawnicza-autocomplete",
    ),
    url(
        r"^organ-przyznajacy-nagrody-autocomplete/$",
        OrganPrzyznajacyNagrodyAutocomplete.as_view(),
        name="organ-przyznajacy-nagrody-autocomplete",
    ),
    url(
        r"^jednostka-widoczna-autocomplete/$",
        WidocznaJednostkaAutocomplete.as_view(),
        name="jednostka-widoczna-autocomplete",
    ),
    url(
        r"^jednostka-autocomplete/$",
        JednostkaAutocomplete.as_view(),
        name="jednostka-autocomplete",
    ),
    url(
        r"^public-jednostka-autocomplete/$",
        PublicJednostkaAutocomplete.as_view(),
        name="public-jednostka-autocomplete",
    ),
    url(
        r"^zewnetrzna-baza-danych-autocomplete/$",
        Zewnetrzna_Baza_DanychAutocomplete.as_view(),
        name="zewnetrzna-baza-danych-autocomplete",
    ),
    url(
        r"^dyscyplina-autocomplete/$",
        Dyscyplina_NaukowaAutocomplete.as_view(),
        name="dyscyplina-autocomplete",
    ),
    url(
        r"^zrodlo-autocomplete/$",
        PublicZrodloAutocomplete.as_view(),
        name="zrodlo-autocomplete",
    ),
    url(
        r"^admin-zrodlo-autocomplete/$",
        ZrodloAutocomplete.as_view(),
        name="admin-zrodlo-autocomplete",
    ),
    url(
        r"^autor-z-uczelni-autocomplete/$",
        AutorZUczelniAutocopmlete.as_view(),
        name="autor-z-uczelni-autocomplete",
    ),
    url(
        r"^autor-autocomplete/$",
        AutorAutocomplete.as_view(),
        name="autor-autocomplete",
    ),
    url(
        r"^public-autor-autocomplete/$",
        PublicAutorAutocomplete.as_view(),
        name="public-autor-autocomplete",
    ),
    url(
        r"^wydawca-autocomplete/$",
        WydawcaAutocomplete.as_view(),
        name="wydawca-autocomplete",
    ),
    url(
        r"^lata-autocomplete/$",
        LataAutocomplete.as_view(),
        name="lata-autocomplete",
    ),
    url(
        r"^navigation-autocomplete/$",
        GlobalNavigationAutocomplete.as_view(),
        name="navigation-autocomplete",
    ),
    url(
        r"^admin-navigation-autocomplete/$",
        AdminNavigationAutocomplete.as_view(),
        name="admin-navigation-autocomplete",
    ),
    url(
        r"^zapisany-jako-autocomplete/$",
        ZapisanyJakoAutocomplete.as_view(),
        name="zapisany-jako-autocomplete",
    ),
    url(
        r"^wydawnictwo-nadrzedne-autocomplete/$",
        Wydawnictwo_NadrzedneAutocomplete.as_view(),
        name="wydawnictwo-nadrzedne-autocomplete",
    ),
    url(
        r"^taggit-tag-autocomplete/$",
        PublicTaggitTagAutocomplete.as_view(),
        name="public-taggit-tag-autocomplete",
    ),
    url(
        r"^public-wydawnictwo-nadrzedne-autocomplete/$",
        PublicWydawnictwo_NadrzedneAutocomplete.as_view(),
        name="public-wydawnictwo-nadrzedne-autocomplete",
    ),
    url(
        r"^podrzedna-publikacja-habilitacyjna-autocomplete/$",
        PodrzednaPublikacjaHabilitacyjnaAutocomplete.as_view(),
        name="podrzedna-publikacja-habilitacyjna-autocomplete",
    ),
    url(
        r"^dyscyplina-naukowa-przypisanie-autocomplete/$",
        Dyscyplina_Naukowa_PrzypisanieAutocomplete.as_view(),
        name="dyscyplina-naukowa-przypisanie-autocomplete",
    ),
]



# -*- coding: utf-8 -*-


from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0022_auto_20150825_2303'),
    ]

    operations = [
        migrations.AddField(
            model_name='charakter_formalny',
            name='artykul_pbn',
            field=models.BooleanField(default=False, help_text=b'Ten charakter formalny zostanie\n    wyeksportowany do PBN jako artyku\xc5\x82', verbose_name=b'Artyku\xc5\x82 w PBN'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='charakter_formalny',
            name='ksiazka_pbn',
            field=models.BooleanField(default=False, help_text=b'Ten charakter formalny zostanie\n    wyeksportowany do PBN jako ksi\xc4\x85\xc5\xbcka', verbose_name=b'Ksi\xc4\x85\xc5\xbcka w PBN'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='charakter_formalny',
            name='rozdzial_pbn',
            field=models.BooleanField(default=False, help_text=b'Ten charakter formalny zostanie\n    wyeksportowany do PBN jako rozdzia\xc5\x82.', verbose_name=b'Rozdzia\xc5\x82 w PBN'),
            preserve_default=True,
        ),
    ]



# Generated by Django 3.2.14 on 2022-07-07 22:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("formdefaults", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="formfielddefaultvalue",
            name="value",
            field=models.JSONField(blank=True, null=True, verbose_name="Wartość"),
        ),
    ]



from bpp.models import Dyscyplina_Zrodla


def test_Dyscyplina_Zrodla___str__(zrodlo, dyscyplina1):
    dz = Dyscyplina_Zrodla.objects.create(zrodlo=zrodlo, dyscyplina=dyscyplina1)
    assert (
        str(dz)
        == 'Przypisanie dyscypliny "memetyka stosowana (1.1)" do źródła "Testowe Źródło"'
    )
